class DataGridViewRow(DataGridViewBand,ICloneable,IDisposable):
 """
 Represents a row in a System.Windows.Forms.DataGridView control.

 

 DataGridViewRow()
 """
 def AdjustRowHeaderBorderStyle(self,dataGridViewAdvancedBorderStyleInput,dataGridViewAdvancedBorderStylePlaceholder,singleVerticalBorderAdded,singleHorizontalBorderAdded,isFirstDisplayedRow,isLastVisibleRow):
  """
  AdjustRowHeaderBorderStyle(self: DataGridViewRow,dataGridViewAdvancedBorderStyleInput: DataGridViewAdvancedBorderStyle,dataGridViewAdvancedBorderStylePlaceholder: DataGridViewAdvancedBorderStyle,singleVerticalBorderAdded: bool,singleHorizontalBorderAdded: bool,isFirstDisplayedRow: bool,isLastVisibleRow: bool) -> DataGridViewAdvancedBorderStyle

  

   Modifies an input row header border style according to the specified criteria.

  

   dataGridViewAdvancedBorderStyleInput: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that represents the row header border 

    style to modify.

  

   dataGridViewAdvancedBorderStylePlaceholder: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that is used to store intermediate 

    changes to the row header border style.

  

   singleVerticalBorderAdded: true to add a single vertical border to the result; otherwise,false.

   singleHorizontalBorderAdded: true to add a single horizontal border to the result; otherwise,false.

   isFirstDisplayedRow: true if the row is the first row displayed in the System.Windows.Forms.DataGridView; otherwise,

    false.

  

   isLastVisibleRow: true if the row is the last row in the System.Windows.Forms.DataGridView that has its 

    System.Windows.Forms.DataGridViewRow.Visible property set to true; otherwise,false.

  

   Returns: A System.Windows.Forms.DataGridViewAdvancedBorderStyle that represents the new border style used.
  """
  pass
 def Clone(self):
  """
  Clone(self: DataGridViewRow) -> object

  

   Creates an exact copy of this row.

   Returns: An System.Object that represents the cloned System.Windows.Forms.DataGridViewRow.
  """
  pass
 def CreateAccessibilityInstance(self,*args):
  """
  CreateAccessibilityInstance(self: DataGridViewRow) -> AccessibleObject

  

   Creates a new accessible object for the System.Windows.Forms.DataGridViewRow.

   Returns: A new System.Windows.Forms.DataGridViewRow.DataGridViewRowAccessibleObject for the 

    System.Windows.Forms.DataGridViewRow.
  """
  pass
 def CreateCells(self,dataGridView,values=None):
  """
  CreateCells(self: DataGridViewRow,dataGridView: DataGridView,*values: Array[object])

   Clears the existing cells and sets their template and values.

  

   dataGridView: A System.Windows.Forms.DataGridView that acts as a template for cell styles.

   values: An array of objects that initialize the reset cells.

  CreateCells(self: DataGridViewRow,dataGridView: DataGridView)

   Clears the existing cells and sets their template according to the supplied 

    System.Windows.Forms.DataGridView template.

  

  

   dataGridView: A System.Windows.Forms.DataGridView that acts as a template for cell styles.
  """
  pass
 def CreateCellsInstance(self,*args):
  """
  CreateCellsInstance(self: DataGridViewRow) -> DataGridViewCellCollection

  

   Constructs a new collection of cells based on this row.

   Returns: The newly created System.Windows.Forms.DataGridViewCellCollection.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridViewBand,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.DataGridViewBand and 

    optionally releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def DrawFocus(self,*args):
  """
  DrawFocus(self: DataGridViewRow,graphics: Graphics,clipBounds: Rectangle,bounds: Rectangle,rowIndex: int,rowState: DataGridViewElementStates,cellStyle: DataGridViewCellStyle,cellsPaintSelectionBackground: bool)

   Draws a focus rectangle around the specified bounds.

  

   graphics: The System.Drawing.Graphics used to paint the System.Windows.Forms.DataGridViewRow.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be painted.

  

   bounds: A System.Drawing.Rectangle that contains the bounds of the System.Windows.Forms.DataGridViewRow 

    that is being painted.

  

   rowIndex: The row index of the cell that is being painted.

   rowState: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values that specifies 

    the state of the row.

  

   cellStyle: The System.Windows.Forms.DataGridViewCellStyle used to paint the focus rectangle.

   cellsPaintSelectionBackground: true to use the System.Windows.Forms.DataGridViewCellStyle.SelectionBackColor property of 

    cellStyle as the color of the focus rectangle; false to use the 

    System.Windows.Forms.DataGridViewCellStyle.BackColor property of cellStyle as the color of the 

    focus rectangle.
  """
  pass
 def GetContextMenuStrip(self,rowIndex):
  """
  GetContextMenuStrip(self: DataGridViewRow,rowIndex: int) -> ContextMenuStrip

  

   Gets the shortcut menu for the row.

  

   rowIndex: The index of the current row.

   Returns: A System.Windows.Forms.ContextMenuStrip that belongs to the System.Windows.Forms.DataGridViewRow 

    at the specified index.
  """
  pass
 def GetErrorText(self,rowIndex):
  """
  GetErrorText(self: DataGridViewRow,rowIndex: int) -> str

  

   Gets the error text for the row at the specified index.

  

   rowIndex: The index of the row that contains the error.

   Returns: A string that describes the error of the row at the specified index.
  """
  pass
 def GetPreferredHeight(self,rowIndex,autoSizeRowMode,fixedWidth):
  """
  GetPreferredHeight(self: DataGridViewRow,rowIndex: int,autoSizeRowMode: DataGridViewAutoSizeRowMode,fixedWidth: bool) -> int

  

   Calculates the ideal height of the specified row based on the specified criteria.

  

   rowIndex: The index of the row whose preferred height is calculated.

   autoSizeRowMode: A System.Windows.Forms.DataGridViewAutoSizeRowMode that specifies an automatic sizing mode.

   fixedWidth: true to calculate the preferred height for a fixed cell width; otherwise,false.

   Returns: The ideal height of the row,in pixels.
  """
  pass
 def GetState(self,rowIndex):
  """
  GetState(self: DataGridViewRow,rowIndex: int) -> DataGridViewElementStates

  

   Returns a value indicating the current state of the row.

  

   rowIndex: The index of the row.

   Returns: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values indicating the 

    row state.
  """
  pass
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewBand)

   Called when the band is associated with a different System.Windows.Forms.DataGridView.
  """
  pass
 def Paint(self,*args):
  """
  Paint(self: DataGridViewRow,graphics: Graphics,clipBounds: Rectangle,rowBounds: Rectangle,rowIndex: int,rowState: DataGridViewElementStates,isFirstDisplayedRow: bool,isLastVisibleRow: bool)

   Paints the current row.

  

   graphics: The System.Drawing.Graphics used to paint the System.Windows.Forms.DataGridViewRow.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be painted.

  

   rowBounds: A System.Drawing.Rectangle that contains the bounds of the System.Windows.Forms.DataGridViewRow 

    that is being painted.

  

   rowIndex: The row index of the cell that is being painted.

   rowState: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values that specifies 

    the state of the row.

  

   isFirstDisplayedRow: true to indicate whether the current row is the first row displayed in the 

    System.Windows.Forms.DataGridView; otherwise,false.

  

   isLastVisibleRow: true to indicate whether the current row is the last row in the 

    System.Windows.Forms.DataGridView that has the System.Windows.Forms.DataGridViewRow.Visible 

    property set to true; otherwise,false.
  """
  pass
 def PaintCells(self,*args):
  """
  PaintCells(self: DataGridViewRow,graphics: Graphics,clipBounds: Rectangle,rowBounds: Rectangle,rowIndex: int,rowState: DataGridViewElementStates,isFirstDisplayedRow: bool,isLastVisibleRow: bool,paintParts: DataGridViewPaintParts)

   Paints the cells in the current row.

  

   graphics: The System.Drawing.Graphics used to paint the System.Windows.Forms.DataGridViewRow.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be painted.

  

   rowBounds: A System.Drawing.Rectangle that contains the bounds of the System.Windows.Forms.DataGridViewRow 

    that is being painted.

  

   rowIndex: The row index of the cell that is being painted.

   rowState: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values that specifies 

    the state of the row.

  

   isFirstDisplayedRow: true to indicate whether the current row is the first row displayed in the 

    System.Windows.Forms.DataGridView; otherwise,false.

  

   isLastVisibleRow: true to indicate whether the current row is the last row in the 

    System.Windows.Forms.DataGridView that has the System.Windows.Forms.DataGridViewRow.Visible 

    property set to true; otherwise,false.

  

   paintParts: A bitwise combination of System.Windows.Forms.DataGridViewPaintParts values indicating the parts 

    of the cells to paint.
  """
  pass
 def PaintHeader(self,*args):
  """
  PaintHeader(self: DataGridViewRow,graphics: Graphics,clipBounds: Rectangle,rowBounds: Rectangle,rowIndex: int,rowState: DataGridViewElementStates,isFirstDisplayedRow: bool,isLastVisibleRow: bool,paintParts: DataGridViewPaintParts)

   Paints the header cell of the current row.

  

   graphics: The System.Drawing.Graphics used to paint the System.Windows.Forms.DataGridViewRow.

   clipBounds: A System.Drawing.Rectangle that represents the area of the System.Windows.Forms.DataGridView 

    that needs to be painted.

  

   rowBounds: A System.Drawing.Rectangle that contains the bounds of the System.Windows.Forms.DataGridViewRow 

    that is being painted.

  

   rowIndex: The row index of the cell that is being painted.

   rowState: A bitwise combination of System.Windows.Forms.DataGridViewElementStates values that specifies 

    the state of the row.

  

   isFirstDisplayedRow: true to indicate that the current row is the first row displayed in the 

    System.Windows.Forms.DataGridView; otherwise,false.

  

   isLastVisibleRow: true to indicate that the current row is the last row in the System.Windows.Forms.DataGridView 

    that has the System.Windows.Forms.DataGridViewRow.Visible property set to true; otherwise,

    false.

  

   paintParts: A bitwise combination of System.Windows.Forms.DataGridViewPaintParts values indicating the parts 

    of the cells to paint.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def SetValues(self,values):
  """
  SetValues(self: DataGridViewRow,*values: Array[object]) -> bool

  

   Sets the values of the row's cells.

  

   values: One or more objects that represent the cell values in the row.-or-An System.Array of 

    System.Object values.

  

   Returns: true if all values have been set; otherwise,false.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridViewRow) -> str

  

   Gets a human-readable string that describes the row.

   Returns: A System.String that describes this row.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 AccessibilityObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.DataGridViewRow.DataGridViewRowAccessibleObject assigned to the System.Windows.Forms.DataGridViewRow.



Get: AccessibilityObject(self: DataGridViewRow) -> AccessibleObject



"""

 Cells=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of cells that populate the row.



Get: Cells(self: DataGridViewRow) -> DataGridViewCellCollection



"""

 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu for the row.



Get: ContextMenuStrip(self: DataGridViewRow) -> ContextMenuStrip



Set: ContextMenuStrip(self: DataGridViewRow)=value

"""

 DataBoundItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data-bound object that populated the row.



Get: DataBoundItem(self: DataGridViewRow) -> object



"""

 DefaultCellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default styles for the row,which are used to render cells in the row unless the styles are overridden.



Get: DefaultCellStyle(self: DataGridViewRow) -> DataGridViewCellStyle



Set: DefaultCellStyle(self: DataGridViewRow)=value

"""

 Displayed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this row is displayed on the screen.



Get: Displayed(self: DataGridViewRow) -> bool



"""

 DividerHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height,in pixels,of the row divider.



Get: DividerHeight(self: DataGridViewRow) -> int



Set: DividerHeight(self: DataGridViewRow)=value

"""

 ErrorText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the error message text for row-level errors.



Get: ErrorText(self: DataGridViewRow) -> str



Set: ErrorText(self: DataGridViewRow)=value

"""

 Frozen=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the row is frozen.



Get: Frozen(self: DataGridViewRow) -> bool



Set: Frozen(self: DataGridViewRow)=value

"""

 HeaderCell=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the row's header cell.



Get: HeaderCell(self: DataGridViewRow) -> DataGridViewRowHeaderCell



Set: HeaderCell(self: DataGridViewRow)=value

"""

 HeaderCellCore=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the header cell of the System.Windows.Forms.DataGridViewBand.



"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current height of the row.



Get: Height(self: DataGridViewRow) -> int



Set: Height(self: DataGridViewRow)=value

"""

 InheritedStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cell style in effect for the row.



Get: InheritedStyle(self: DataGridViewRow) -> DataGridViewCellStyle



"""

 IsNewRow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the row is the row for new records.



Get: IsNewRow(self: DataGridViewRow) -> bool



"""

 IsRow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the band represents a row.



"""

 MinimumHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the minimum height of the row.



Get: MinimumHeight(self: DataGridViewRow) -> int



Set: MinimumHeight(self: DataGridViewRow)=value

"""

 ReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the row is read-only.



Get: ReadOnly(self: DataGridViewRow) -> bool



Set: ReadOnly(self: DataGridViewRow)=value

"""

 Resizable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether users can resize the row or indicating that the behavior is inherited from the System.Windows.Forms.DataGridView.AllowUserToResizeRows property.



Get: Resizable(self: DataGridViewRow) -> DataGridViewTriState



Set: Resizable(self: DataGridViewRow)=value

"""

 Selected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the row is selected.



Get: Selected(self: DataGridViewRow) -> bool



Set: Selected(self: DataGridViewRow)=value

"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current state of the row.



Get: State(self: DataGridViewRow) -> DataGridViewElementStates



"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the row is visible.



Get: Visible(self: DataGridViewRow) -> bool



Set: Visible(self: DataGridViewRow)=value

"""


 DataGridViewRowAccessibleObject=None




class WriteStreamClosedEventArgs(EventArgs):
 """ WriteStreamClosedEventArgs() """
 Error=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Error(self: WriteStreamClosedEventArgs) -> Exception



"""





class DefaultDllImportSearchPathsAttribute(Attribute,_Attribute):
 """ DefaultDllImportSearchPathsAttribute(paths: DllImportSearchPath) """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,paths):
  """ __new__(cls: type,paths: DllImportSearchPath) """
  pass
 Paths=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Paths(self: DefaultDllImportSearchPathsAttribute) -> DllImportSearchPath



"""





class KnownColor(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the known system colors.

 

 enum KnownColor,values: ActiveBorder (1),ActiveCaption (2),ActiveCaptionText (3),AliceBlue (28),AntiqueWhite (29),AppWorkspace (4),Aqua (30),Aquamarine (31),Azure (32),Beige (33),Bisque (34),Black (35),BlanchedAlmond (36),Blue (37),BlueViolet (38),Brown (39),BurlyWood (40),ButtonFace (168),ButtonHighlight (169),ButtonShadow (170),CadetBlue (41),Chartreuse (42),Chocolate (43),Control (5),ControlDark (6),ControlDarkDark (7),ControlLight (8),ControlLightLight (9),ControlText (10),Coral (44),CornflowerBlue (45),Cornsilk (46),Crimson (47),Cyan (48),DarkBlue (49),DarkCyan (50),DarkGoldenrod (51),DarkGray (52),DarkGreen (53),DarkKhaki (54),DarkMagenta (55),DarkOliveGreen (56),DarkOrange (57),DarkOrchid (58),DarkRed (59),DarkSalmon (60),DarkSeaGreen (61),DarkSlateBlue (62),DarkSlateGray (63),DarkTurquoise (64),DarkViolet (65),DeepPink (66),DeepSkyBlue (67),Desktop (11),DimGray (68),DodgerBlue (69),Firebrick (70),FloralWhite (71),ForestGreen (72),Fuchsia (73),Gainsboro (74),GhostWhite (75),Gold (76),Goldenrod (77),GradientActiveCaption (171),GradientInactiveCaption (172),Gray (78),GrayText (12),Green (79),GreenYellow (80),Highlight (13),HighlightText (14),Honeydew (81),HotPink (82),HotTrack (15),InactiveBorder (16),InactiveCaption (17),InactiveCaptionText (18),IndianRed (83),Indigo (84),Info (19),InfoText (20),Ivory (85),Khaki (86),Lavender (87),LavenderBlush (88),LawnGreen (89),LemonChiffon (90),LightBlue (91),LightCoral (92),LightCyan (93),LightGoldenrodYellow (94),LightGray (95),LightGreen (96),LightPink (97),LightSalmon (98),LightSeaGreen (99),LightSkyBlue (100),LightSlateGray (101),LightSteelBlue (102),LightYellow (103),Lime (104),LimeGreen (105),Linen (106),Magenta (107),Maroon (108),MediumAquamarine (109),MediumBlue (110),MediumOrchid (111),MediumPurple (112),MediumSeaGreen (113),MediumSlateBlue (114),MediumSpringGreen (115),MediumTurquoise (116),MediumVioletRed (117),Menu (21),MenuBar (173),MenuHighlight (174),MenuText (22),MidnightBlue (118),MintCream (119),MistyRose (120),Moccasin (121),NavajoWhite (122),Navy (123),OldLace (124),Olive (125),OliveDrab (126),Orange (127),OrangeRed (128),Orchid (129),PaleGoldenrod (130),PaleGreen (131),PaleTurquoise (132),PaleVioletRed (133),PapayaWhip (134),PeachPuff (135),Peru (136),Pink (137),Plum (138),PowderBlue (139),Purple (140),Red (141),RosyBrown (142),RoyalBlue (143),SaddleBrown (144),Salmon (145),SandyBrown (146),ScrollBar (23),SeaGreen (147),SeaShell (148),Sienna (149),Silver (150),SkyBlue (151),SlateBlue (152),SlateGray (153),Snow (154),SpringGreen (155),SteelBlue (156),Tan (157),Teal (158),Thistle (159),Tomato (160),Transparent (27),Turquoise (161),Violet (162),Wheat (163),White (164),WhiteSmoke (165),Window (24),WindowFrame (25),WindowText (26),Yellow (166),YellowGreen (167)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ActiveBorder=None
 ActiveCaption=None
 ActiveCaptionText=None
 AliceBlue=None
 AntiqueWhite=None
 AppWorkspace=None
 Aqua=None
 Aquamarine=None
 Azure=None
 Beige=None
 Bisque=None
 Black=None
 BlanchedAlmond=None
 Blue=None
 BlueViolet=None
 Brown=None
 BurlyWood=None
 ButtonFace=None
 ButtonHighlight=None
 ButtonShadow=None
 CadetBlue=None
 Chartreuse=None
 Chocolate=None
 Control=None
 ControlDark=None
 ControlDarkDark=None
 ControlLight=None
 ControlLightLight=None
 ControlText=None
 Coral=None
 CornflowerBlue=None
 Cornsilk=None
 Crimson=None
 Cyan=None
 DarkBlue=None
 DarkCyan=None
 DarkGoldenrod=None
 DarkGray=None
 DarkGreen=None
 DarkKhaki=None
 DarkMagenta=None
 DarkOliveGreen=None
 DarkOrange=None
 DarkOrchid=None
 DarkRed=None
 DarkSalmon=None
 DarkSeaGreen=None
 DarkSlateBlue=None
 DarkSlateGray=None
 DarkTurquoise=None
 DarkViolet=None
 DeepPink=None
 DeepSkyBlue=None
 Desktop=None
 DimGray=None
 DodgerBlue=None
 Firebrick=None
 FloralWhite=None
 ForestGreen=None
 Fuchsia=None
 Gainsboro=None
 GhostWhite=None
 Gold=None
 Goldenrod=None
 GradientActiveCaption=None
 GradientInactiveCaption=None
 Gray=None
 GrayText=None
 Green=None
 GreenYellow=None
 Highlight=None
 HighlightText=None
 Honeydew=None
 HotPink=None
 HotTrack=None
 InactiveBorder=None
 InactiveCaption=None
 InactiveCaptionText=None
 IndianRed=None
 Indigo=None
 Info=None
 InfoText=None
 Ivory=None
 Khaki=None
 Lavender=None
 LavenderBlush=None
 LawnGreen=None
 LemonChiffon=None
 LightBlue=None
 LightCoral=None
 LightCyan=None
 LightGoldenrodYellow=None
 LightGray=None
 LightGreen=None
 LightPink=None
 LightSalmon=None
 LightSeaGreen=None
 LightSkyBlue=None
 LightSlateGray=None
 LightSteelBlue=None
 LightYellow=None
 Lime=None
 LimeGreen=None
 Linen=None
 Magenta=None
 Maroon=None
 MediumAquamarine=None
 MediumBlue=None
 MediumOrchid=None
 MediumPurple=None
 MediumSeaGreen=None
 MediumSlateBlue=None
 MediumSpringGreen=None
 MediumTurquoise=None
 MediumVioletRed=None
 Menu=None
 MenuBar=None
 MenuHighlight=None
 MenuText=None
 MidnightBlue=None
 MintCream=None
 MistyRose=None
 Moccasin=None
 NavajoWhite=None
 Navy=None
 OldLace=None
 Olive=None
 OliveDrab=None
 Orange=None
 OrangeRed=None
 Orchid=None
 PaleGoldenrod=None
 PaleGreen=None
 PaleTurquoise=None
 PaleVioletRed=None
 PapayaWhip=None
 PeachPuff=None
 Peru=None
 Pink=None
 Plum=None
 PowderBlue=None
 Purple=None
 Red=None
 RosyBrown=None
 RoyalBlue=None
 SaddleBrown=None
 Salmon=None
 SandyBrown=None
 ScrollBar=None
 SeaGreen=None
 SeaShell=None
 Sienna=None
 Silver=None
 SkyBlue=None
 SlateBlue=None
 SlateGray=None
 Snow=None
 SpringGreen=None
 SteelBlue=None
 Tan=None
 Teal=None
 Thistle=None
 Tomato=None
 Transparent=None
 Turquoise=None
 value__=None
 Violet=None
 Wheat=None
 White=None
 WhiteSmoke=None
 Window=None
 WindowFrame=None
 WindowText=None
 Yellow=None
 YellowGreen=None




class DriveInfo(object,ISerializable):
 """
 Provides access to information on a drive.

 

 DriveInfo(driveName: str)
 """
 @staticmethod
 def GetDrives():
  """
  GetDrives() -> Array[DriveInfo]

  

   Retrieves the drive names of all logical drives on a computer.

   Returns: An array of type System.IO.DriveInfo that represents the logical drives on a computer.
  """
  pass
 def ToString(self):
  """
  ToString(self: DriveInfo) -> str

  

   Returns a drive name as a string.

   Returns: The name of the drive.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,driveName):
  """ __new__(cls: type,driveName: str) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 AvailableFreeSpace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates the amount of available free space on a drive.



Get: AvailableFreeSpace(self: DriveInfo) -> Int64



"""

 DriveFormat=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the file system,such as NTFS or FAT32.



Get: DriveFormat(self: DriveInfo) -> str



"""

 DriveType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the drive type.



Get: DriveType(self: DriveInfo) -> DriveType



"""

 IsReady=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a drive is ready.



Get: IsReady(self: DriveInfo) -> bool



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of a drive.



Get: Name(self: DriveInfo) -> str



"""

 RootDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the root directory of a drive.



Get: RootDirectory(self: DriveInfo) -> DirectoryInfo



"""

 TotalFreeSpace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total amount of free space available on a drive.



Get: TotalFreeSpace(self: DriveInfo) -> Int64



"""

 TotalSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total size of storage space on a drive.



Get: TotalSize(self: DriveInfo) -> Int64



"""

 VolumeLabel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the volume label of a drive.



Get: VolumeLabel(self: DriveInfo) -> str



Set: VolumeLabel(self: DriveInfo)=value

"""





class File(object):
 """ Provides static methods for the creation,copying,deletion,moving,and opening of files,and aids in the creation of System.IO.FileStream objects. """
 @staticmethod
 def AppendAllLines(path,contents,encoding=None):
  """ AppendAllLines(path: str,contents: IEnumerable[str],encoding: Encoding)AppendAllLines(path: str,contents: IEnumerable[str]) """
  pass
 @staticmethod
 def AppendAllText(path,contents,encoding=None):
  """
  AppendAllText(path: str,contents: str,encoding: Encoding)

   Appends the specified string to the file,creating the file if it does not already exist.

  

   path: The file to append the specified string to.

   contents: The string to append to the file.

   encoding: The character encoding to use.

  AppendAllText(path: str,contents: str)

   Opens a file,appends the specified string to the file,and then closes the file. If the file 

    does not exist,this method creates a file,writes the specified string to the file,then closes 

    the file.

  

  

   path: The file to append the specified string to.

   contents: The string to append to the file.
  """
  pass
 @staticmethod
 def AppendText(path):
  """
  AppendText(path: str) -> StreamWriter

  

   Creates a System.IO.StreamWriter that appends UTF-8 encoded text to an existing file.

  

   path: The path to the file to append to.

   Returns: A StreamWriter that appends UTF-8 encoded text to an existing file.
  """
  pass
 @staticmethod
 def Copy(sourceFileName,destFileName,overwrite=None):
  """
  Copy(sourceFileName: str,destFileName: str,overwrite: bool)

   Copies an existing file to a new file. Overwriting a file of the same name is allowed.

  

   sourceFileName: The file to copy.

   destFileName: The name of the destination file. This cannot be a directory.

   overwrite: true if the destination file can be overwritten; otherwise,false.

  Copy(sourceFileName: str,destFileName: str)

   Copies an existing file to a new file. Overwriting a file of the same name is not allowed.

  

   sourceFileName: The file to copy.

   destFileName: The name of the destination file. This cannot be a directory or an existing file.
  """
  pass
 @staticmethod
 def Create(path,bufferSize=None,options=None,fileSecurity=None):
  """
  Create(path: str,bufferSize: int,options: FileOptions) -> FileStream

  

   Creates or overwrites the specified file,specifying a buffer size and a System.IO.FileOptions 

    value that describes how to create or overwrite the file.

  

  

   path: The name of the file.

   bufferSize: The number of bytes buffered for reads and writes to the file.

   options: One of the System.IO.FileOptions values that describes how to create or overwrite the file.

   Returns: A new file with the specified buffer size.

  Create(path: str,bufferSize: int,options: FileOptions,fileSecurity: FileSecurity) -> FileStream

  

   Creates or overwrites the specified file with the specified buffer size,file options,and file 

    security.

  

  

   path: The name of the file.

   bufferSize: The number of bytes buffered for reads and writes to the file.

   options: One of the System.IO.FileOptions values that describes how to create or overwrite the file.

   fileSecurity: One of the System.Security.AccessControl.FileSecurity values that determines the access control 

    and audit security for the file.

  

   Returns: A new file with the specified buffer size,file options,and file security.

  Create(path: str) -> FileStream

  

   Creates or overwrites a file in the specified path.

  

   path: The path and name of the file to create.

   Returns: A System.IO.FileStream that provides read/write access to the file specified in path.

  Create(path: str,bufferSize: int) -> FileStream

  

   Creates or overwrites the specified file.

  

   path: The name of the file.

   bufferSize: The number of bytes buffered for reads and writes to the file.

   Returns: A System.IO.FileStream with the specified buffer size that provides read/write access to the 

    file specified in path.
  """
  pass
 @staticmethod
 def CreateText(path):
  """
  CreateText(path: str) -> StreamWriter

  

   Creates or opens a file for writing UTF-8 encoded text.

  

   path: The file to be opened for writing.

   Returns: A System.IO.StreamWriter that writes to the specified file using UTF-8 encoding.
  """
  pass
 @staticmethod
 def Decrypt(path):
  """
  Decrypt(path: str)

   Decrypts a file that was encrypted by the current account using the 

    System.IO.File.Encrypt(System.String) method.

  

  

   path: A path that describes a file to decrypt.
  """
  pass
 @staticmethod
 def Delete(path):
  """
  Delete(path: str)

   Deletes the specified file.

  

   path: The name of the file to be deleted. Wildcard characters are not supported.
  """
  pass
 @staticmethod
 def Encrypt(path):
  """
  Encrypt(path: str)

   Encrypts a file so that only the account used to encrypt the file can decrypt it.

  

   path: A path that describes a file to encrypt.
  """
  pass
 @staticmethod
 def Exists(path):
  """
  Exists(path: str) -> bool

  

   Determines whether the specified file exists.

  

   path: The file to check.

   Returns: true if the caller has the required permissions and path contains the name of an existing file; 

    otherwise,false. This method also returns false if path is null,an invalid path,or a 

    zero-length string. If the caller does not have sufficient permissions to read the specified 

    file,no exception is thrown and the method returns false regardless of the existence of path.
  """
  pass
 @staticmethod
 def GetAccessControl(path,includeSections=None):
  """
  GetAccessControl(path: str,includeSections: AccessControlSections) -> FileSecurity

  

   Gets a System.Security.AccessControl.FileSecurity object that encapsulates the specified type of 

    access control list (ACL) entries for a particular file.

  

  

   path: The path to a file containing a System.Security.AccessControl.FileSecurity object that describes 

    the file's access control list (ACL) information.

  

   includeSections: One of the System.Security.AccessControl.AccessControlSections values that specifies the type of 

    access control list (ACL) information to receive.

  

   Returns: A System.Security.AccessControl.FileSecurity object that encapsulates the access control rules 

    for the file described by the path parameter.

  

  GetAccessControl(path: str) -> FileSecurity

  

   Gets a System.Security.AccessControl.FileSecurity object that encapsulates the access control 

    list (ACL) entries for a specified file.

  

  

   path: The path to a file containing a System.Security.AccessControl.FileSecurity object that describes 

    the file's access control list (ACL) information.

  

   Returns: A System.Security.AccessControl.FileSecurity object that encapsulates the access control rules 

    for the file described by the path parameter.
  """
  pass
 @staticmethod
 def GetAttributes(path):
  """
  GetAttributes(path: str) -> FileAttributes

  

   Gets the System.IO.FileAttributes of the file on the path.

  

   path: The path to the file.

   Returns: The System.IO.FileAttributes of the file on the path.
  """
  pass
 @staticmethod
 def GetCreationTime(path):
  """
  GetCreationTime(path: str) -> DateTime

  

   Returns the creation date and time of the specified file or directory.

  

   path: The file or directory for which to obtain creation date and time information.

   Returns: A System.DateTime structure set to the creation date and time for the specified file or 

    directory. This value is expressed in local time.
  """
  pass
 @staticmethod
 def GetCreationTimeUtc(path):
  """
  GetCreationTimeUtc(path: str) -> DateTime

  

   Returns the creation date and time,in coordinated universal time (UTC),of the specified file 

    or directory.

  

  

   path: The file or directory for which to obtain creation date and time information.

   Returns: A System.DateTime structure set to the creation date and time for the specified file or 

    directory. This value is expressed in UTC time.
  """
  pass
 @staticmethod
 def GetLastAccessTime(path):
  """
  GetLastAccessTime(path: str) -> DateTime

  

   Returns the date and time the specified file or directory was last accessed.

  

   path: The file or directory for which to obtain access date and time information.

   Returns: A System.DateTime structure set to the date and time that the specified file or directory was 

    last accessed. This value is expressed in local time.
  """
  pass
 @staticmethod
 def GetLastAccessTimeUtc(path):
  """
  GetLastAccessTimeUtc(path: str) -> DateTime

  

   Returns the date and time,in coordinated universal time (UTC),that the specified file or 

    directory was last accessed.

  

  

   path: The file or directory for which to obtain access date and time information.

   Returns: A System.DateTime structure set to the date and time that the specified file or directory was 

    last accessed. This value is expressed in UTC time.
  """
  pass
 @staticmethod
 def GetLastWriteTime(path):
  """
  GetLastWriteTime(path: str) -> DateTime

  

   Returns the date and time the specified file or directory was last written to.

  

   path: The file or directory for which to obtain write date and time information.

   Returns: A System.DateTime structure set to the date and time that the specified file or directory was 

    last written to. This value is expressed in local time.
  """
  pass
 @staticmethod
 def GetLastWriteTimeUtc(path):
  """
  GetLastWriteTimeUtc(path: str) -> DateTime

  

   Returns the date and time,in coordinated universal time (UTC),that the specified file or 

    directory was last written to.

  

  

   path: The file or directory for which to obtain write date and time information.

   Returns: A System.DateTime structure set to the date and time that the specified file or directory was 

    last written to. This value is expressed in UTC time.
  """
  pass
 @staticmethod
 def Move(sourceFileName,destFileName):
  """
  Move(sourceFileName: str,destFileName: str)

   Moves a specified file to a new location,providing the option to specify a new file name.

  

   sourceFileName: The name of the file to move.

   destFileName: The new path for the file.
  """
  pass
 @staticmethod
 def Open(path,mode,access=None,share=None):
  """
  Open(path: str,mode: FileMode,access: FileAccess,share: FileShare) -> FileStream

  

   Opens a System.IO.FileStream on the specified path,having the specified mode with read,write,

    or read/write access and the specified sharing option.

  

  

   path: The file to open.

   mode: A System.IO.FileMode value that specifies whether a file is created if one does not exist,and 

    determines whether the contents of existing files are retained or overwritten.

  

   access: A System.IO.FileAccess value that specifies the operations that can be performed on the file.

   share: A System.IO.FileShare value specifying the type of access other threads have to the file.

   Returns: A System.IO.FileStream on the specified path,having the specified mode with read,write,or 

    read/write access and the specified sharing option.

  

  Open(path: str,mode: FileMode,access: FileAccess) -> FileStream

  

   Opens a System.IO.FileStream on the specified path,with the specified mode and access.

  

   path: The file to open.

   mode: A System.IO.FileMode value that specifies whether a file is created if one does not exist,and 

    determines whether the contents of existing files are retained or overwritten.

  

   access: A System.IO.FileAccess value that specifies the operations that can be performed on the file.

   Returns: An unshared System.IO.FileStream that provides access to the specified file,with the specified 

    mode and access.

  

  Open(path: str,mode: FileMode) -> FileStream

  

   Opens a System.IO.FileStream on the specified path with read/write access.

  

   path: The file to open.

   mode: A System.IO.FileMode value that specifies whether a file is created if one does not exist,and 

    determines whether the contents of existing files are retained or overwritten.

  

   Returns: A System.IO.FileStream opened in the specified mode and path,with read/write access and not 

    shared.
  """
  pass
 @staticmethod
 def OpenRead(path):
  """
  OpenRead(path: str) -> FileStream

  

   Opens an existing file for reading.

  

   path: The file to be opened for reading.

   Returns: A read-only System.IO.FileStream on the specified path.
  """
  pass
 @staticmethod
 def OpenText(path):
  """
  OpenText(path: str) -> StreamReader

  

   Opens an existing UTF-8 encoded text file for reading.

  

   path: The file to be opened for reading.

   Returns: A System.IO.StreamReader on the specified path.
  """
  pass
 @staticmethod
 def OpenWrite(path):
  """
  OpenWrite(path: str) -> FileStream

  

   Opens an existing file or creates a new file for writing.

  

   path: The file to be opened for writing.

   Returns: An unshared System.IO.FileStream object on the specified path with System.IO.FileAccess.Write 

    access.
  """
  pass
 @staticmethod
 def ReadAllBytes(path):
  """
  ReadAllBytes(path: str) -> Array[Byte]

  

   Opens a binary file,reads the contents of the file into a byte array,and then closes the file.

  

   path: The file to open for reading.

   Returns: A byte array containing the contents of the file.
  """
  pass
 @staticmethod
 def ReadAllLines(path,encoding=None):
  """
  ReadAllLines(path: str,encoding: Encoding) -> Array[str]

  

   Opens a file,reads all lines of the file with the specified encoding,and then closes the file.

  

   path: The file to open for reading.

   encoding: The encoding applied to the contents of the file.

   Returns: A string array containing all lines of the file.

  ReadAllLines(path: str) -> Array[str]

  

   Opens a text file,reads all lines of the file,and then closes the file.

  

   path: The file to open for reading.

   Returns: A string array containing all lines of the file.
  """
  pass
 @staticmethod
 def ReadAllText(path,encoding=None):
  """
  ReadAllText(path: str,encoding: Encoding) -> str

  

   Opens a file,reads all lines of the file with the specified encoding,and then closes the file.

  

   path: The file to open for reading.

   encoding: The encoding applied to the contents of the file.

   Returns: A string containing all lines of the file.

  ReadAllText(path: str) -> str

  

   Opens a text file,reads all lines of the file,and then closes the file.

  

   path: The file to open for reading.

   Returns: A string containing all lines of the file.
  """
  pass
 @staticmethod
 def ReadLines(path,encoding=None):
  """
  ReadLines(path: str,encoding: Encoding) -> IEnumerable[str]

  

   Read the lines of a file that has a specified encoding.

  

   path: The file to read.

   encoding: The encoding that is applied to the contents of the file.

   Returns: All the lines of the file,or the lines that are the result of a query.

  ReadLines(path: str) -> IEnumerable[str]

  

   Reads the lines of a file.

  

   path: The file to read.

   Returns: All the lines of the file,or the lines that are the result of a query.
  """
  pass
 @staticmethod
 def Replace(sourceFileName,destinationFileName,destinationBackupFileName,ignoreMetadataErrors=None):
  """
  Replace(sourceFileName: str,destinationFileName: str,destinationBackupFileName: str,ignoreMetadataErrors: bool)

   Replaces the contents of a specified file with the contents of another file,deleting the 

    original file,and creating a backup of the replaced file and optionally ignores merge errors.

  

  

   sourceFileName: The name of a file that replaces the file specified by destinationFileName.

   destinationFileName: The name of the file being replaced.

   destinationBackupFileName: The name of the backup file.

   ignoreMetadataErrors: true to ignore merge errors (such as attributes and access control lists (ACLs)) from the 

    replaced file to the replacement file; otherwise,false.

  

  Replace(sourceFileName: str,destinationFileName: str,destinationBackupFileName: str)

   Replaces the contents of a specified file with the contents of another file,deleting the 

    original file,and creating a backup of the replaced file.

  

  

   sourceFileName: The name of a file that replaces the file specified by destinationFileName.

   destinationFileName: The name of the file being replaced.

   destinationBackupFileName: The name of the backup file.
  """
  pass
 @staticmethod
 def SetAccessControl(path,fileSecurity):
  """
  SetAccessControl(path: str,fileSecurity: FileSecurity)

   Applies access control list (ACL) entries described by a 

    System.Security.AccessControl.FileSecurity object to the specified file.

  

  

   path: A file to add or remove access control list (ACL) entries from.

   fileSecurity: A System.Security.AccessControl.FileSecurity object that describes an ACL entry to apply to the 

    file described by the path parameter.
  """
  pass
 @staticmethod
 def SetAttributes(path,fileAttributes):
  """
  SetAttributes(path: str,fileAttributes: FileAttributes)

   Sets the specified System.IO.FileAttributes of the file on the specified path.

  

   path: The path to the file.

   fileAttributes: A bitwise combination of the enumeration values.
  """
  pass
 @staticmethod
 def SetCreationTime(path,creationTime):
  """
  SetCreationTime(path: str,creationTime: DateTime)

   Sets the date and time the file was created.

  

   path: The file for which to set the creation date and time information.

   creationTime: A System.DateTime containing the value to set for the creation date and time of path. This value 

    is expressed in local time.
  """
  pass
 @staticmethod
 def SetCreationTimeUtc(path,creationTimeUtc):
  """
  SetCreationTimeUtc(path: str,creationTimeUtc: DateTime)

   Sets the date and time,in coordinated universal time (UTC),that the file was created.

  

   path: The file for which to set the creation date and time information.

   creationTimeUtc: A System.DateTime containing the value to set for the creation date and time of path. This value 

    is expressed in UTC time.
  """
  pass
 @staticmethod
 def SetLastAccessTime(path,lastAccessTime):
  """
  SetLastAccessTime(path: str,lastAccessTime: DateTime)

   Sets the date and time the specified file was last accessed.

  

   path: The file for which to set the access date and time information.

   lastAccessTime: A System.DateTime containing the value to set for the last access date and time of path. This 

    value is expressed in local time.
  """
  pass
 @staticmethod
 def SetLastAccessTimeUtc(path,lastAccessTimeUtc):
  """
  SetLastAccessTimeUtc(path: str,lastAccessTimeUtc: DateTime)

   Sets the date and time,in coordinated universal time (UTC),that the specified file was last 

    accessed.

  

  

   path: The file for which to set the access date and time information.

   lastAccessTimeUtc: A System.DateTime containing the value to set for the last access date and time of path. This 

    value is expressed in UTC time.
  """
  pass
 @staticmethod
 def SetLastWriteTime(path,lastWriteTime):
  """
  SetLastWriteTime(path: str,lastWriteTime: DateTime)

   Sets the date and time that the specified file was last written to.

  

   path: The file for which to set the date and time information.

   lastWriteTime: A System.DateTime containing the value to set for the last write date and time of path. This 

    value is expressed in local time.
  """
  pass
 @staticmethod
 def SetLastWriteTimeUtc(path,lastWriteTimeUtc):
  """
  SetLastWriteTimeUtc(path: str,lastWriteTimeUtc: DateTime)

   Sets the date and time,in coordinated universal time (UTC),that the specified file was last 

    written to.

  

  

   path: The file for which to set the date and time information.

   lastWriteTimeUtc: A System.DateTime containing the value to set for the last write date and time of path. This 

    value is expressed in UTC time.
  """
  pass
 @staticmethod
 def WriteAllBytes(path,bytes):
  """
  WriteAllBytes(path: str,bytes: Array[Byte])

   Creates a new file,writes the specified byte array to the file,and then closes the file. If 

    the target file already exists,it is overwritten.

  

  

   path: The file to write to.

   bytes: The bytes to write to the file.
  """
  pass
 @staticmethod
 def WriteAllLines(path,contents,encoding=None):
  """
  WriteAllLines(path: str,contents: IEnumerable[str])WriteAllLines(path: str,contents: IEnumerable[str],encoding: Encoding)WriteAllLines(path: str,contents: Array[str])

   Creates a new file,write the specified string array to the file,and then closes the file.

  

   path: The file to write to.

   contents: The string array to write to the file.

  WriteAllLines(path: str,contents: Array[str],encoding: Encoding)

   Creates a new file,writes the specified string array to the file by using the specified 

    encoding,and then closes the file.

  

  

   path: The file to write to.

   contents: The string array to write to the file.

   encoding: An System.Text.Encoding object that represents the character encoding applied to the string 

    array.
  """
  pass
 @staticmethod
 def WriteAllText(path,contents,encoding=None):
  """
  WriteAllText(path: str,contents: str,encoding: Encoding)

   Creates a new file,writes the specified string to the file using the specified encoding,and 

    then closes the file. If the target file already exists,it is overwritten.

  

  

   path: The file to write to.

   contents: The string to write to the file.

   encoding: The encoding to apply to the string.

  WriteAllText(path: str,contents: str)

   Creates a new file,writes the specified string to the file,and then closes the file. If the 

    target file already exists,it is overwritten.

  

  

   path: The file to write to.

   contents: The string to write to the file.
  """
  pass
 __all__=[
  'AppendAllLines',
  'AppendAllText',
  'AppendText',
  'Copy',
  'Create',
  'CreateText',
  'Decrypt',
  'Delete',
  'Encrypt',
  'Exists',
  'GetAccessControl',
  'GetAttributes',
  'GetCreationTime',
  'GetCreationTimeUtc',
  'GetLastAccessTime',
  'GetLastAccessTimeUtc',
  'GetLastWriteTime',
  'GetLastWriteTimeUtc',
  'Move',
  'Open',
  'OpenRead',
  'OpenText',
  'OpenWrite',
  'ReadAllBytes',
  'ReadAllLines',
  'ReadAllText',
  'ReadLines',
  'Replace',
  'SetAccessControl',
  'SetAttributes',
  'SetCreationTime',
  'SetCreationTimeUtc',
  'SetLastAccessTime',
  'SetLastAccessTimeUtc',
  'SetLastWriteTime',
  'SetLastWriteTimeUtc',
  'WriteAllBytes',
  'WriteAllLines',
  'WriteAllText',
 ]




class SyntaxCheck(object):
 """ Provides methods to verify the machine name and path conform to a specific syntax. This class cannot be inherited. """
 @staticmethod
 def CheckMachineName(value):
  """
  CheckMachineName(value: str) -> bool

  

   Checks the syntax of the machine name to confirm that it does not contain "\".

  

   value: A string containing the machine name to check.

   Returns: true if value matches the proper machine name format; otherwise,false.
  """
  pass
 @staticmethod
 def CheckPath(value):
  """
  CheckPath(value: str) -> bool

  

   Checks the syntax of the path to see whether it starts with "\\".

  

   value: A string containing the path to check.

   Returns: true if value matches the proper path format; otherwise,false.
  """
  pass
 @staticmethod
 def CheckRootedPath(value):
  """
  CheckRootedPath(value: str) -> bool

  

   Checks the syntax of the path to see if it starts with "\" or drive letter "C:".

  

   value: A string containing the path to check.

   Returns: true if value matches the proper path format; otherwise,false.
  """
  pass
 __all__=[
  'CheckMachineName',
  'CheckPath',
  'CheckRootedPath',
 ]




class GenericAcl(object,ICollection,IEnumerable):
 """ Represents an access control list (ACL) and is the base class for the System.Security.AccessControl.CommonAcl,System.Security.AccessControl.DiscretionaryAcl,System.Security.AccessControl.RawAcl,and System.Security.AccessControl.SystemAcl classes. """
 def CopyTo(self,array,index):
  """
  CopyTo(self: GenericAcl,array: Array[GenericAce],index: int)

   Copies each System.Security.AccessControl.GenericAce of the current 

    System.Security.AccessControl.GenericAcl into the specified array.

  

  

   array: The array into which copies of the System.Security.AccessControl.GenericAce objects contained by 

    the current System.Security.AccessControl.GenericAcl are placed.

  

   index: The zero-based index of array where the copying begins.
  """
  pass
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: GenericAcl,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.GenericAcl object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.GenericAcl is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: GenericAcl) -> AceEnumerator

  

   Returns a new instance of the System.Security.AccessControl.AceEnumerator class.

   Returns: The Security.AccessControl.AceEnumerator that this method returns.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.GenericAcl object. This length should be used before marshaling the ACL into a binary array with the System.Security.AccessControl.GenericAcl.GetBinaryForm method.



Get: BinaryLength(self: GenericAcl) -> int



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of access control entries (ACEs) in the current System.Security.AccessControl.GenericAcl object.



Get: Count(self: GenericAcl) -> int



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """This property is always set to false. It is implemented only because it is required for the implementation of the System.Collections.ICollection interface.



Get: IsSynchronized(self: GenericAcl) -> bool



"""

 Revision=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the revision level of the System.Security.AccessControl.GenericAcl.



Get: Revision(self: GenericAcl) -> Byte



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """This property always returns null. It is implemented only because it is required for the implementation of the System.Collections.ICollection interface.



Get: SyncRoot(self: GenericAcl) -> object



"""


 AclRevision=None
 AclRevisionDS=None
 MaxBinaryLength=65535




class TypeLibFuncFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the original settings of the FUNCFLAGS in the COM type library from where this method was imported.

 

 enum (flags) TypeLibFuncFlags,values: FBindable (4),FDefaultBind (32),FDefaultCollelem (256),FDisplayBind (16),FHidden (64),FImmediateBind (4096),FNonBrowsable (1024),FReplaceable (2048),FRequestEdit (8),FRestricted (1),FSource (2),FUiDefault (512),FUsesGetLastError (128)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FBindable=None
 FDefaultBind=None
 FDefaultCollelem=None
 FDisplayBind=None
 FHidden=None
 FImmediateBind=None
 FNonBrowsable=None
 FReplaceable=None
 FRequestEdit=None
 FRestricted=None
 FSource=None
 FUiDefault=None
 FUsesGetLastError=None
 value__=None




class SizeFConverter(TypeConverter):
 """
 Converts System.Drawing.SizeF objects from one type to another.

 

 SizeFConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: SizeFConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Returns a value indicating whether the converter can convert from the type specified to the 

    System.Drawing.SizeF type,using the specified context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext through which additional context can be supplied.

   sourceType: A System.Type the represents the type you wish to convert from.

   Returns: true to indicate the conversion can be performed; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: SizeFConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns a value indicating whether the System.Drawing.SizeFConverter can convert a 

    System.Drawing.SizeF to the specified type.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext through which additional context can be supplied.

   destinationType: A System.Type that represents the type you want to convert from.

   Returns: true if this converter can perform the conversion otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: SizeFConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: The System.Globalization.CultureInfo to use as the current culture.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: SizeFConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo. If null is passed,the current culture is assumed.

   value: The System.Object to convert.

   destinationType: The System.Type to convert the value parameter to.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def CreateInstance(self,*__args):
  """
  CreateInstance(self: SizeFConverter,context: ITypeDescriptorContext,propertyValues: IDictionary) -> object

  

   Creates an instance of a System.Drawing.SizeF with the specified property values using the 

    specified context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext through which additional context can be supplied.

   propertyValues: An System.Collections.IDictionary containing property names and values.

   Returns: An System.Object representing the new System.Drawing.SizeF,or null if the object cannot be 

    created.
  """
  pass
 def GetCreateInstanceSupported(self,context=None):
  """
  GetCreateInstanceSupported(self: SizeFConverter,context: ITypeDescriptorContext) -> bool

  

   Returns a value indicating whether changing a value on this object requires a call to the 

    erload:System.Drawing.SizeFConverter.CreateInstance method to create a new value.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context. This may be null.

   Returns: Always returns true.
  """
  pass
 def GetProperties(self,*__args):
  """
  GetProperties(self: SizeFConverter,context: ITypeDescriptorContext,value: object,attributes: Array[Attribute]) -> PropertyDescriptorCollection

  

   Retrieves a set of properties for the System.Drawing.SizeF type using the specified context and 

    attributes.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext through which additional context can be supplied.

   value: The System.Object to return properties for.

   attributes: An array of System.Attribute objects that describe the properties.

   Returns: A System.ComponentModel.PropertyDescriptorCollection containing the properties.
  """
  pass
 def GetPropertiesSupported(self,context=None):
  """
  GetPropertiesSupported(self: SizeFConverter,context: ITypeDescriptorContext) -> bool

  

   Returns whether the System.Drawing.SizeF type supports properties.

  

   context: An System.ComponentModel.ITypeDescriptorContext through which additional context can be supplied.

   Returns: Always returns true.
  """
  pass



class NotifyIcon(Component,IComponent,IDisposable):
 """
 Specifies a component that creates an icon in the notification area. This class cannot be inherited.

 

 NotifyIcon()

 NotifyIcon(container: IContainer)
 """
 def Dispose(self):
  """ Dispose(self: NotifyIcon,disposing: bool) """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ShowBalloonTip(self,timeout,tipTitle=None,tipText=None,tipIcon=None):
  """
  ShowBalloonTip(self: NotifyIcon,timeout: int,tipTitle: str,tipText: str,tipIcon: ToolTipIcon)

   Displays a balloon tip with the specified title,text,and icon in the taskbar for the specified 

    time period.

  

  

   timeout: The time period,in milliseconds,the balloon tip should display.

   tipTitle: The title to display on the balloon tip.

   tipText: The text to display on the balloon tip.

   tipIcon: One of the System.Windows.Forms.ToolTipIcon values.

  ShowBalloonTip(self: NotifyIcon,timeout: int)

   Displays a balloon tip in the taskbar for the specified time period.

  

   timeout: The time period,in milliseconds,the balloon tip should display.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,container=None):
  """
  __new__(cls: type)

  __new__(cls: type,container: IContainer)
  """
  pass
 def __str__(self,*args):
  pass
 BalloonTipIcon=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the icon to display on the balloon tip associated with the System.Windows.Forms.NotifyIcon.



Get: BalloonTipIcon(self: NotifyIcon) -> ToolTipIcon



Set: BalloonTipIcon(self: NotifyIcon)=value

"""

 BalloonTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text to display on the balloon tip associated with the System.Windows.Forms.NotifyIcon.



Get: BalloonTipText(self: NotifyIcon) -> str



Set: BalloonTipText(self: NotifyIcon)=value

"""

 BalloonTipTitle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the title of the balloon tip displayed on the System.Windows.Forms.NotifyIcon.



Get: BalloonTipTitle(self: NotifyIcon) -> str



Set: BalloonTipTitle(self: NotifyIcon)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 ContextMenu=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu for the icon.



Get: ContextMenu(self: NotifyIcon) -> ContextMenu



Set: ContextMenu(self: NotifyIcon)=value

"""

 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu associated with the System.Windows.Forms.NotifyIcon.



Get: ContextMenuStrip(self: NotifyIcon) -> ContextMenuStrip



Set: ContextMenuStrip(self: NotifyIcon)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Icon=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current icon.



Get: Icon(self: NotifyIcon) -> Icon



Set: Icon(self: NotifyIcon)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an object that contains data about the System.Windows.Forms.NotifyIcon.



Get: Tag(self: NotifyIcon) -> object



Set: Tag(self: NotifyIcon)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ToolTip text displayed when the mouse pointer rests on a notification area icon.



Get: Text(self: NotifyIcon) -> str



Set: Text(self: NotifyIcon)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the icon is visible in the notification area of the taskbar.



Get: Visible(self: NotifyIcon) -> bool



Set: Visible(self: NotifyIcon)=value

"""


 BalloonTipClicked=None
 BalloonTipClosed=None
 BalloonTipShown=None
 Click=None
 DoubleClick=None
 MouseClick=None
 MouseDoubleClick=None
 MouseDown=None
 MouseMove=None
 MouseUp=None




class IServiceProvider:
 """ Defines a mechanism for retrieving a service object; that is,an object that provides custom support to other objects. """
 def GetService(self,serviceType):
  """
  GetService(self: IServiceProvider,serviceType: Type) -> object

  

   Gets the service object of the specified type.

  

   serviceType: An object that specifies the type of service object to get.

   Returns: A service object of type serviceType.-or- null if there is no service object of type serviceType.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class ManagedToNativeComInteropStubAttribute(Attribute,_Attribute):
 """
 Provides support for user customization of interop stubs in managed-to-COM interop scenarios.

 

 ManagedToNativeComInteropStubAttribute(classType: Type,methodName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,classType,methodName):
  """ __new__(cls: type,classType: Type,methodName: str) """
  pass
 ClassType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the class that contains the required stub method.



Get: ClassType(self: ManagedToNativeComInteropStubAttribute) -> Type



"""

 MethodName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the stub method.



Get: MethodName(self: ManagedToNativeComInteropStubAttribute) -> str



"""





class IObserver:
 # no doc
 def OnCompleted(self):
  """
  OnCompleted(self: IObserver[T])

   Notifies the observer that the provider has finished sending push-based notifications.
  """
  pass
 def OnError(self,error):
  """
  OnError(self: IObserver[T],error: Exception)

   Notifies the observer that the provider has experienced an error condition.

  

   error: An object that provides additional information about the error.
  """
  pass
 def OnNext(self,value):
  """
  OnNext(self: IObserver[T],value: T)

   Provides the observer with new data.

  

   value: The current notification information.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class AggregateException(Exception,ISerializable,_Exception):
 """
 Represents one or more errors that occur during application execution.

 

 AggregateException()

 AggregateException(message: str)

 AggregateException(message: str,innerException: Exception)

 AggregateException(innerExceptions: IEnumerable[Exception])

 AggregateException(*innerExceptions: Array[Exception])

 AggregateException(message: str,innerExceptions: IEnumerable[Exception])

 AggregateException(message: str,*innerExceptions: Array[Exception])
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def Flatten(self):
  """
  Flatten(self: AggregateException) -> AggregateException

  

   Flattens an System.AggregateException instances into a single,new instance.

   Returns: A new,flattened System.AggregateException.
  """
  pass
 def GetBaseException(self):
  """
  GetBaseException(self: AggregateException) -> Exception

  

   Returns the System.AggregateException that is the root cause of this exception.

   Returns: Returns the System.AggregateException that is the root cause of this exception.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: AggregateException,info: SerializationInfo,context: StreamingContext)

   Initializes a new instance of the System.AggregateException class with serialized data.

  

   info: The object that holds the serialized object data.

   context: The contextual information about the source or destination.
  """
  pass
 def Handle(self,predicate):
  """ Handle(self: AggregateException,predicate: Func[Exception,bool]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def ToString(self):
  """
  ToString(self: AggregateException) -> str

  

   Creates and returns a string representation of the current System.AggregateException.

   Returns: A string representation of the current exception.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,innerExceptions: IEnumerable[Exception])

  __new__(cls: type,*innerExceptions: Array[Exception])

  __new__(cls: type,message: str,innerExceptions: IEnumerable[Exception])

  __new__(cls: type,message: str,*innerExceptions: Array[Exception])

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 InnerExceptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a read-only collection of the System.Exception instances that caused the current exception.



Get: InnerExceptions(self: AggregateException) -> ReadOnlyCollection[Exception]



"""





class ListChangedEventArgs(EventArgs):
 """
 Provides data for the System.ComponentModel.IBindingList.ListChanged event.

 

 ListChangedEventArgs(listChangedType: ListChangedType,newIndex: int)

 ListChangedEventArgs(listChangedType: ListChangedType,newIndex: int,propDesc: PropertyDescriptor)

 ListChangedEventArgs(listChangedType: ListChangedType,propDesc: PropertyDescriptor)

 ListChangedEventArgs(listChangedType: ListChangedType,newIndex: int,oldIndex: int)
 """
 @staticmethod
 def __new__(self,listChangedType,*__args):
  """
  __new__(cls: type,listChangedType: ListChangedType,newIndex: int)

  __new__(cls: type,listChangedType: ListChangedType,newIndex: int,propDesc: PropertyDescriptor)

  __new__(cls: type,listChangedType: ListChangedType,propDesc: PropertyDescriptor)

  __new__(cls: type,listChangedType: ListChangedType,newIndex: int,oldIndex: int)
  """
  pass
 ListChangedType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of change.



Get: ListChangedType(self: ListChangedEventArgs) -> ListChangedType



"""

 NewIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the item affected by the change.



Get: NewIndex(self: ListChangedEventArgs) -> int



"""

 OldIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the old index of an item that has been moved.



Get: OldIndex(self: ListChangedEventArgs) -> int



"""

 PropertyDescriptor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.ComponentModel.PropertyDescriptor that was added,changed,or deleted.



Get: PropertyDescriptor(self: ListChangedEventArgs) -> PropertyDescriptor



"""





class SelectedGridItemChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.PropertyGrid.SelectedGridItemChanged event of the System.Windows.Forms.PropertyGrid control.

 

 SelectedGridItemChangedEventArgs(oldSel: GridItem,newSel: GridItem)
 """
 @staticmethod
 def __new__(self,oldSel,newSel):
  """ __new__(cls: type,oldSel: GridItem,newSel: GridItem) """
  pass
 NewSelection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the newly selected System.Windows.Forms.GridItem.



Get: NewSelection(self: SelectedGridItemChangedEventArgs) -> GridItem



"""

 OldSelection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previously selected System.Windows.Forms.GridItem.



Get: OldSelection(self: SelectedGridItemChangedEventArgs) -> GridItem



"""





class PrintControllerWithStatusDialog(PrintController):
 """
 Controls how a document is printed from a Windows Forms application.

 

 PrintControllerWithStatusDialog(underlyingController: PrintController)

 PrintControllerWithStatusDialog(underlyingController: PrintController,dialogTitle: str)
 """
 def OnEndPage(self,document,e):
  """
  OnEndPage(self: PrintControllerWithStatusDialog,document: PrintDocument,e: PrintPageEventArgs)

   Completes the control sequence that determines when and how to print a page of a document.

  

   document: A System.Drawing.Printing.PrintDocument that represents the document currently being printed.

   e: A System.Drawing.Printing.PrintPageEventArgs that contains the event data.
  """
  pass
 def OnEndPrint(self,document,e):
  """
  OnEndPrint(self: PrintControllerWithStatusDialog,document: PrintDocument,e: PrintEventArgs)

   Completes the control sequence that determines when and how to print a document.

  

   document: A System.Drawing.Printing.PrintDocument that represents the document currently being printed.

   e: A System.Drawing.Printing.PrintPageEventArgs that contains the event data.
  """
  pass
 def OnStartPage(self,document,e):
  """
  OnStartPage(self: PrintControllerWithStatusDialog,document: PrintDocument,e: PrintPageEventArgs) -> Graphics

  

   Begins the control sequence that determines when and how to print a page of a document.

  

   document: A System.Drawing.Printing.PrintDocument that represents the document currently being printed.

   e: A System.Drawing.Printing.PrintPageEventArgs that contains the event data.

   Returns: A System.Drawing.Graphics object that represents a page from a 

    System.Drawing.Printing.PrintDocument.
  """
  pass
 def OnStartPrint(self,document,e):
  """
  OnStartPrint(self: PrintControllerWithStatusDialog,document: PrintDocument,e: PrintEventArgs)

   Begins the control sequence that determines when and how to print a document.

  

   document: A System.Drawing.Printing.PrintDocument that represents the document currently being printed.

   e: A System.Drawing.Printing.PrintEventArgs that contains the event data.
  """
  pass
 @staticmethod
 def __new__(self,underlyingController,dialogTitle=None):
  """
  __new__(cls: type,underlyingController: PrintController)

  __new__(cls: type,underlyingController: PrintController,dialogTitle: str)
  """
  pass
 IsPreview=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating this System.Windows.Forms.PrintControllerWithStatusDialog is used for print preview.



Get: IsPreview(self: PrintControllerWithStatusDialog) -> bool



"""





class InkCanvasStrokeCollectedEventArgs(RoutedEventArgs):
 """
 Provides data for the System.Windows.Controls.InkCanvas.StrokeCollected event.

 

 InkCanvasStrokeCollectedEventArgs(stroke: Stroke)
 """
 @staticmethod
 def __new__(self,stroke):
  """ __new__(cls: type,stroke: Stroke) """
  pass
 Stroke=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the stroke that was added to the System.Windows.Controls.InkCanvas.



Get: Stroke(self: InkCanvasStrokeCollectedEventArgs) -> Stroke



"""





class InkCanvasGestureEventArgs(RoutedEventArgs):
 """
 Provides data for the System.Windows.Controls.InkCanvas.Gesture event.

 

 InkCanvasGestureEventArgs(strokes: StrokeCollection,gestureRecognitionResults: IEnumerable[GestureRecognitionResult])
 """
 def GetGestureRecognitionResults(self):
  """
  GetGestureRecognitionResults(self: InkCanvasGestureEventArgs) -> ReadOnlyCollection[GestureRecognitionResult]

  

   Returns results from the gesture recognizer.

   Returns: A collection of possible application gestures that the 

    System.Windows.Controls.InkCanvasGestureEventArgs.Strokes might be.
  """
  pass
 @staticmethod
 def __new__(self,strokes,gestureRecognitionResults):
  """ __new__(cls: type,strokes: StrokeCollection,gestureRecognitionResults: IEnumerable[GestureRecognitionResult]) """
  pass
 Cancel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that indicates whether strokes should be considered a gesture.



Get: Cancel(self: InkCanvasGestureEventArgs) -> bool



Set: Cancel(self: InkCanvasGestureEventArgs)=value

"""

 Strokes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the strokes that represent the possible gesture.



Get: Strokes(self: InkCanvasGestureEventArgs) -> StrokeCollection



"""





class ItemCollection(CollectionView,ICollectionView,IEnumerable,INotifyCollectionChanged,INotifyPropertyChanged,IList,ICollection,IEditableCollectionViewAddNewItem,IEditableCollectionView,ICollectionViewLiveShaping,IItemProperties,IWeakEventListener):
 """ Holds the list of items that constitute the content of an System.Windows.Controls.ItemsControl. """
 def Add(self,newItem):
  """
  Add(self: ItemCollection,newItem: object) -> int

  

   Adds an item to the System.Windows.Controls.ItemCollection.

  

   newItem: The item to add to the collection.

   Returns: The zero-based index at which the object is added or -1 if the item cannot be added.
  """
  pass
 def add_CollectionChanged(self,*args):
  """ add_CollectionChanged(self: CollectionView,value: NotifyCollectionChangedEventHandler) """
  pass
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: CollectionView,value: PropertyChangedEventHandler) """
  pass
 def Clear(self):
  """
  Clear(self: ItemCollection)

   Clears the collection and releases the references on all items currently in the collection.
  """
  pass
 def ClearChangeLog(self,*args):
  """
  ClearChangeLog(self: CollectionView)

   Clears any pending changes from the change log.
  """
  pass
 def ClearPendingChanges(self,*args):
  """ ClearPendingChanges(self: CollectionView) """
  pass
 def Contains(self,containItem):
  """
  Contains(self: ItemCollection,containItem: object) -> bool

  

   Returns a value that indicates whether the specified item is in this view.

  

   containItem: The object to check.

   Returns: true to indicate that the item belongs to this collection and passes the active filter; 

    otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: ItemCollection,array: Array,index: int)

   Copies the elements of the collection to an array,starting at a particular array index.

  

   array: The destination array to copy to.

   index: The zero-based index in the destination array.
  """
  pass
 def DeferRefresh(self):
  """
  DeferRefresh(self: ItemCollection) -> IDisposable

  

   Enters a defer cycle that you can use to merge changes to the view and delay automatic refresh.

   Returns: An System.IDisposable object that you can use to dispose of the calling object.
  """
  pass
 def GetEnumerator(self,*args):
  """ GetEnumerator(self: ItemCollection) -> IEnumerator """
  pass
 def GetItemAt(self,index):
  """
  GetItemAt(self: ItemCollection,index: int) -> object

  

   Returns the item at the specified zero-based index in this view.

  

   index: The zero-based index at which the item is located.

   Returns: The item at the specified zero-based index in this view.
  """
  pass
 def IndexOf(self,item):
  """
  IndexOf(self: ItemCollection,item: object) -> int

  

   Returns the index in this collection where the specified item is located.

  

   item: The object to look for in the collection.

   Returns: The index of the item in the collection,or -1 if the item does not exist in the collection.
  """
  pass
 def Insert(self,insertIndex,insertItem):
  """
  Insert(self: ItemCollection,insertIndex: int,insertItem: object)

   Inserts an element into the collection at the specified index.

  

   insertIndex: The zero-based index at which to insert the item.

   insertItem: The item to insert.
  """
  pass
 def MoveCurrentTo(self,item):
  """
  MoveCurrentTo(self: ItemCollection,item: object) -> bool

  

   Sets the specified item in the collection as the 

    System.Windows.Controls.ItemCollection.CurrentItem.

  

  

   item: The item to set as the System.Windows.Controls.ItemCollection.CurrentItem.

   Returns: true to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def MoveCurrentToFirst(self):
  """
  MoveCurrentToFirst(self: ItemCollection) -> bool

  

   Sets the first item in the view as the System.Windows.Controls.ItemCollection.CurrentItem.

   Returns: true to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def MoveCurrentToLast(self):
  """
  MoveCurrentToLast(self: ItemCollection) -> bool

  

   Sets the last item in the view as the System.Windows.Controls.ItemCollection.CurrentItem.

   Returns: true to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def MoveCurrentToNext(self):
  """
  MoveCurrentToNext(self: ItemCollection) -> bool

  

   Sets the item after the System.Windows.Controls.ItemCollection.CurrentItem in the view as the 

    System.Windows.Controls.ItemCollection.CurrentItem.

  

   Returns: true to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def MoveCurrentToPosition(self,position):
  """
  MoveCurrentToPosition(self: ItemCollection,position: int) -> bool

  

   Sets the item at the specified index to be the 

    System.Windows.Controls.ItemCollection.CurrentItem in the view.

  

  

   position: The zero-based index of the item to set as the 

    System.Windows.Controls.ItemCollection.CurrentItem.

  

   Returns: true to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def MoveCurrentToPrevious(self):
  """
  MoveCurrentToPrevious(self: ItemCollection) -> bool

  

   Sets the item before the System.Windows.Controls.ItemCollection.CurrentItem in the view as the 

    System.Windows.Controls.ItemCollection.CurrentItem.

  

   Returns: true  to indicate that the resulting System.Windows.Controls.ItemCollection.CurrentItem is an 

    item within the view; otherwise,false.
  """
  pass
 def OKToChangeCurrent(self,*args):
  """
  OKToChangeCurrent(self: CollectionView) -> bool

  

   Returns a value that indicates whether the view can change which item is the 

    System.Windows.Data.CollectionView.CurrentItem.

  

   Returns: false if a listener cancels the change; otherwise,true.
  """
  pass
 def OnAllowsCrossThreadChangesChanged(self,*args):
  """ OnAllowsCrossThreadChangesChanged(self: CollectionView) """
  pass
 def OnBeginChangeLogging(self,*args):
  """
  OnBeginChangeLogging(self: CollectionView,args: NotifyCollectionChangedEventArgs)

   Called by the base class to notify the derived class that an 

    System.Collections.Specialized.INotifyCollectionChanged.CollectionChanged event has been posted 

    to the message queue.

  

  

   args: The System.Collections.Specialized.NotifyCollectionChangedEventArgs object that is added to the 

    change log.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: CollectionView,sender: object,args: NotifyCollectionChangedEventArgs)

   Raises the System.Windows.Data.CollectionView.CollectionChanged event.

  

   sender: The sender of the event.

   args: The System.Collections.Specialized.NotifyCollectionChangedEventArgs object to pass to the event 

    handler.

  

  OnCollectionChanged(self: CollectionView,args: NotifyCollectionChangedEventArgs)

   Raises the System.Windows.Data.CollectionView.CollectionChanged event.

  

   args: The System.Collections.Specialized.NotifyCollectionChangedEventArgs object to pass to the event 

    handler.
  """
  pass
 def OnCurrentChanged(self,*args):
  """
  OnCurrentChanged(self: CollectionView)

   Raises the System.Windows.Data.CollectionView.CurrentChanged event.
  """
  pass
 def OnCurrentChanging(self,*args):
  """
  OnCurrentChanging(self: CollectionView,args: CurrentChangingEventArgs)

   Raises the System.Windows.Data.CollectionView.CurrentChanging event with the specified arguments.

  

   args: Information about the event.

  OnCurrentChanging(self: CollectionView)

   Raises a System.Windows.Data.CollectionView.CurrentChanging event that is not cancelable.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: CollectionView,e: PropertyChangedEventArgs)

   Raises the System.ComponentModel.INotifyPropertyChanged.PropertyChanged event using the 

    specified arguments.

  

  

   e: Arguments of the event being raised.
  """
  pass
 def PassesFilter(self,item):
  """
  PassesFilter(self: ItemCollection,item: object) -> bool

  

   Returns a value that indicates whether the specified item belongs to this view.

  

   item: The object to test.

   Returns: true to indicate that the specified item belongs to this view or there is no filter set on this 

    collection view; otherwise,false.
  """
  pass
 def ProcessCollectionChanged(self,*args):
  """
  ProcessCollectionChanged(self: CollectionView,args: NotifyCollectionChangedEventArgs)

   When overridden in a derived class,processes a single change on the UI�thread.

  

   args: The System.Collections.Specialized.NotifyCollectionChangedEventArgs object to process.
  """
  pass
 def ProcessPendingChanges(self,*args):
  """ ProcessPendingChanges(self: CollectionView) """
  pass
 def RefreshOrDefer(self,*args):
  """
  RefreshOrDefer(self: CollectionView)

   Refreshes the view or specifies that the view needs to be refreshed when the defer cycle 

    completes.
  """
  pass
 def RefreshOverride(self,*args):
  """ RefreshOverride(self: ItemCollection) """
  pass
 def Remove(self,removeItem):
  """
  Remove(self: ItemCollection,removeItem: object)

   Removes the specified item reference from the collection or view.

  

   removeItem: The object to remove.
  """
  pass
 def RemoveAt(self,removeIndex):
  """
  RemoveAt(self: ItemCollection,removeIndex: int)

   Removes the item at the specified index of the collection or view.

  

   removeIndex: The zero-based index of the item to remove.
  """
  pass
 def remove_CollectionChanged(self,*args):
  """ remove_CollectionChanged(self: CollectionView,value: NotifyCollectionChangedEventHandler) """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: CollectionView,value: PropertyChangedEventHandler) """
  pass
 def SetCurrent(self,*args):
  """
  SetCurrent(self: CollectionView,newItem: object,newPosition: int,count: int)

   Sets the specified item and index as the values of the 

    System.Windows.Data.CollectionView.CurrentItem and 

    System.Windows.Data.CollectionView.CurrentPosition properties. This method can be called from a 

    constructor of a derived class.

  

  

   newItem: The item to set as the System.Windows.Data.CollectionView.CurrentItem.

   newPosition: The value to set as the System.Windows.Data.CollectionView.CurrentPosition property value.

   count: The number of items in the System.Windows.Data.CollectionView.

  SetCurrent(self: CollectionView,newItem: object,newPosition: int)

   Sets the specified item and index as the values of the 

    System.Windows.Data.CollectionView.CurrentItem and 

    System.Windows.Data.CollectionView.CurrentPosition properties.

  

  

   newItem: The item to set as the System.Windows.Data.CollectionView.CurrentItem.

   newPosition: The value to set as the System.Windows.Data.CollectionView.CurrentPosition property value.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 AllowsCrossThreadChanges=property(lambda self: object(),lambda self,v: None,lambda self: None)

 CanChangeLiveFiltering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CanChangeLiveFiltering(self: ItemCollection) -> bool



"""

 CanChangeLiveGrouping=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CanChangeLiveGrouping(self: ItemCollection) -> bool



"""

 CanChangeLiveSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CanChangeLiveSorting(self: ItemCollection) -> bool



"""

 CanFilter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this collection view supports filtering.



Get: CanFilter(self: ItemCollection) -> bool



"""

 CanGroup=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this collection view supports grouping.



Get: CanGroup(self: ItemCollection) -> bool



"""

 CanSort=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this collection view supports sorting.



Get: CanSort(self: ItemCollection) -> bool



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of records in the collection.



Get: Count(self: ItemCollection) -> int



"""

 CurrentItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current item in the view.



Get: CurrentItem(self: ItemCollection) -> object



"""

 CurrentPosition=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the ordinal position of the current item within the view.



Get: CurrentPosition(self: ItemCollection) -> int



"""

 Filter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a callback used to determine if an item is suitable for inclusion in the view.



Get: Filter(self: ItemCollection) -> Predicate[object]



Set: Filter(self: ItemCollection)=value

"""

 GroupDescriptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of System.ComponentModel.GroupDescription objects that defines how to group the items.



Get: GroupDescriptions(self: ItemCollection) -> ObservableCollection[GroupDescription]



"""

 Groups=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the top-level groups that are constructed according to the System.Windows.Controls.ItemCollection.GroupDescriptions.



Get: Groups(self: ItemCollection) -> ReadOnlyObservableCollection[object]



"""

 IsCurrentAfterLast=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the current item of the view is beyond the end of the collection.



Get: IsCurrentAfterLast(self: ItemCollection) -> bool



"""

 IsCurrentBeforeFirst=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the current item of the view is beyond the beginning of the collection.



Get: IsCurrentBeforeFirst(self: ItemCollection) -> bool



"""

 IsCurrentInSync=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.Windows.Data.CollectionView.CurrentItem is at the System.Windows.Data.CollectionView.CurrentPosition.



"""

 IsDynamic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the underlying collection provides change notifications.



"""

 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the resulting (filtered) view is empty.



Get: IsEmpty(self: ItemCollection) -> bool



"""

 IsLiveFiltering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsLiveFiltering(self: ItemCollection) -> Nullable[bool]



Set: IsLiveFiltering(self: ItemCollection)=value

"""

 IsLiveGrouping=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsLiveGrouping(self: ItemCollection) -> Nullable[bool]



Set: IsLiveGrouping(self: ItemCollection)=value

"""

 IsLiveSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsLiveSorting(self: ItemCollection) -> Nullable[bool]



Set: IsLiveSorting(self: ItemCollection)=value

"""

 LiveFilteringProperties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LiveFilteringProperties(self: ItemCollection) -> ObservableCollection[str]



"""

 LiveGroupingProperties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LiveGroupingProperties(self: ItemCollection) -> ObservableCollection[str]



"""

 LiveSortingProperties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LiveSortingProperties(self: ItemCollection) -> ObservableCollection[str]



"""

 NeedsRefresh=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the collection needs to be refreshed.



Get: NeedsRefresh(self: ItemCollection) -> bool



"""

 SortDescriptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of System.ComponentModel.SortDescription objects that describe how the items in the collection are sorted in the view.



Get: SortDescriptions(self: ItemCollection) -> SortDescriptionCollection



"""

 SourceCollection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the unsorted and unfiltered collection that underlies this collection view.



Get: SourceCollection(self: ItemCollection) -> IEnumerable



"""

 UpdatedOutsideDispatcher=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether it has been necessary to update the change log because a System.Windows.Data.CollectionView.CollectionChanged notification has been received on a different thread without first entering the user interface (UI) thread dispatcher.



"""





class TYPEATTR(object):
 """ Use System.Runtime.InteropServices.ComTypes.TYPEATTR instead. """
 cbAlignment=None
 cbSizeInstance=None
 cbSizeVft=None
 cFuncs=None
 cImplTypes=None
 cVars=None
 dwReserved=None
 guid=None
 idldescType=None
 lcid=None
 lpstrSchema=None
 MEMBER_ID_NIL=-1
 memidConstructor=None
 memidDestructor=None
 tdescAlias=None
 typekind=None
 wMajorVerNum=None
 wMinorVerNum=None
 wTypeFlags=None




class IWebProxyScript:
 """ Provides the base interface to load and execute scripts for automatic proxy detection. """
 def Close(self):
  """
  Close(self: IWebProxyScript)

   Closes a script.
  """
  pass
 def Load(self,scriptLocation,script,helperType):
  """
  Load(self: IWebProxyScript,scriptLocation: Uri,script: str,helperType: Type) -> bool

  

   Loads a script.

  

   scriptLocation: Internal only.

   script: Internal only.

   helperType: Internal only.

   Returns: A System.Boolean indicating whether the script was successfully loaded.
  """
  pass
 def Run(self,url,host):
  """
  Run(self: IWebProxyScript,url: str,host: str) -> str

  

   Runs a script.

  

   url: Internal only.

   host: Internal only.

   Returns: A System.String.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DrawTreeNodeEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.TreeView.DrawNode event.

 

 DrawTreeNodeEventArgs(graphics: Graphics,node: TreeNode,bounds: Rectangle,state: TreeNodeStates)
 """
 @staticmethod
 def __new__(self,graphics,node,bounds,state):
  """ __new__(cls: type,graphics: Graphics,node: TreeNode,bounds: Rectangle,state: TreeNodeStates) """
  pass
 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the System.Windows.Forms.TreeNode to draw.



Get: Bounds(self: DrawTreeNodeEventArgs) -> Rectangle



"""

 DrawDefault=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.TreeNode should be drawn by the operating system rather than being owner drawn.



Get: DrawDefault(self: DrawTreeNodeEventArgs) -> bool



Set: DrawDefault(self: DrawTreeNodeEventArgs)=value

"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Drawing.Graphics object used to draw the System.Windows.Forms.TreeNode.



Get: Graphics(self: DrawTreeNodeEventArgs) -> Graphics



"""

 Node=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.TreeNode to draw.



Get: Node(self: DrawTreeNodeEventArgs) -> TreeNode



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current state of the System.Windows.Forms.TreeNode to draw.



Get: State(self: DrawTreeNodeEventArgs) -> TreeNodeStates



"""





class FtpWebResponse(WebResponse,ISerializable,IDisposable):
 """ Encapsulates a File Transfer Protocol (FTP) server's response to a request. """
 def Close(self):
  """
  Close(self: FtpWebResponse)

   Frees the resources held by the response.
  """
  pass
 def Dispose(self):
  """ Dispose(self: WebResponse,disposing: bool) """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: WebResponse,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data that is needed to 

    serialize the target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def GetResponseStream(self):
  """
  GetResponseStream(self: FtpWebResponse) -> Stream

  

   Retrieves the stream that contains response data sent from an FTP server.

   Returns: A readable System.IO.Stream instance that contains data returned with the response; otherwise,

    System.IO.Stream.Null if no response data was returned by the server.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 BannerMessage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the message sent by the FTP server when a connection is established prior to logon.



Get: BannerMessage(self: FtpWebResponse) -> str



"""

 ContentLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the data received from the FTP server.



Get: ContentLength(self: FtpWebResponse) -> Int64



"""

 ExitMessage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the message sent by the server when the FTP session is ending.



Get: ExitMessage(self: FtpWebResponse) -> str



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an empty System.Net.WebHeaderCollection object.



Get: Headers(self: FtpWebResponse) -> WebHeaderCollection



"""

 LastModified=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date and time that a file on an FTP server was last modified.



Get: LastModified(self: FtpWebResponse) -> DateTime



"""

 ResponseUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URI that sent the response to the request.



Get: ResponseUri(self: FtpWebResponse) -> Uri



"""

 StatusCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the most recent status code sent from the FTP server.



Get: StatusCode(self: FtpWebResponse) -> FtpStatusCode



"""

 StatusDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets text that describes a status code sent from the FTP server.



Get: StatusDescription(self: FtpWebResponse) -> str



"""

 SupportsHeaders=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SupportsHeaders(self: FtpWebResponse) -> bool



"""

 WelcomeMessage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the message sent by the FTP server when authentication is complete.



Get: WelcomeMessage(self: FtpWebResponse) -> str



"""





class TransportType(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines transport types for the System.Net.SocketPermission and System.Net.Sockets.Socket classes.

 

 enum TransportType,values: All (3),Connectionless (1),ConnectionOriented (2),Tcp (2),Udp (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 All=None
 Connectionless=None
 ConnectionOriented=None
 Tcp=None
 Udp=None
 value__=None




class ClockCollection(object,ICollection[Clock],IEnumerable[Clock],IEnumerable):
 """ Represents an ordered collection of System.Windows.Media.Animation.Clock objects. """
 def Add(self,item):
  """
  Add(self: ClockCollection,item: Clock)

   Adds a new System.Windows.Media.Animation.Clock object to the end of this 

    System.Windows.Media.Animation.ClockCollection.

  

  

   item: The object to add.
  """
  pass
 def Clear(self):
  """
  Clear(self: ClockCollection)

   Removes all items from this System.Windows.Media.Animation.ClockCollection.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: ClockCollection,item: Clock) -> bool

  

   Indicates whether the System.Windows.Media.Animation.ClockCollection contains the specified 

    System.Windows.Media.Animation.Clock object.

  

  

   item: The object to locate.

   Returns: true if item is found; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: ClockCollection,array: Array[Clock],index: int)

   Copies the System.Windows.Media.Animation.Clock objects of this 

    System.Windows.Media.Animation.ClockCollection to an array of Clocks,starting at the specified 

    index position.

  

  

   array: The destination array.

   index: The zero-based index position where copying begins.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(objA: ClockCollection,objB: ClockCollection) -> bool

  

   Indicates whether the two specified System.Windows.Media.Animation.ClockCollection collections 

    are equal.

  

  

   objA: The first value to compare.

   objB: The second value to compare.

   Returns: true if objA and objB are equal; otherwise,false.

  Equals(self: ClockCollection,obj: object) -> bool

  

   Indicates whether this instance is equal to the specified object.

  

   obj: The object to compare with this instance.

   Returns: true if obj is equal to this instance; otherwise false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ClockCollection) -> int

  

   Returns a 32-bit signed integer hash code representing this instance.

   Returns: A 32-bit signed integer.
  """
  pass
 def Remove(self,item):
  """
  Remove(self: ClockCollection,item: Clock) -> bool

  

   Removes the specified System.Windows.Media.Animation.Clock from the 

    System.Windows.Media.Animation.ClockCollection.

  

  

   item: The object to remove.

   Returns: true if item was successfully removed; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__(self: ICollection[Clock],item: Clock) -> bool """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __ne__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of items contained in this System.Windows.Media.Animation.ClockCollection.



Get: Count(self: ClockCollection) -> int



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Windows.Media.Animation.ClockCollection is read-only.



Get: IsReadOnly(self: ClockCollection) -> bool



"""





# encoding: utf-8
# module System.Windows.Documents.DocumentStructures calls itself DocumentStructures
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class BlockElement(object):
 """
 Do not use.

 

 BlockElement()
 """

class SemanticBasicElement(BlockElement):
 """ An XML element in the markup for XML Paper Specification (XPS) documents. """

class FigureStructure(SemanticBasicElement,IAddChild,IEnumerable[NamedElement],IEnumerable):
 """
 Represents a drawing,chart,or diagram in a document.

 

 FigureStructure()
 """
 def Add(self,element):
  """
  Add(self: FigureStructure,element: NamedElement)

   Add a named element to the figure.

  

   element: The element to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[NamedElement](enumerable: IEnumerable[NamedElement],value: NamedElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class ListItemStructure(SemanticBasicElement,IAddChild,IEnumerable[BlockElement],IEnumerable):
 """
 Represents an item in a list or outline.

 

 ListItemStructure()
 """
 def Add(self,element):
  """
  Add(self: ListItemStructure,element: BlockElement)

   Adds a block to a list item.

  

   element: The block to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[BlockElement](enumerable: IEnumerable[BlockElement],value: BlockElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 Marker=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the numeral,character,or bullet symbol for the list item as it appears in the formatting markup of the document.



Get: Marker(self: ListItemStructure) -> str



Set: Marker(self: ListItemStructure)=value

"""



class ListStructure(SemanticBasicElement,IAddChild,IEnumerable[ListItemStructure],IEnumerable):
 """
 Represents a list of items in a document.

 

 ListStructure()
 """
 def Add(self,listItem):
  """
  Add(self: ListStructure,listItem: ListItemStructure)

   Adds a list item to the list.

  

   listItem: The list item to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[ListItemStructure](enumerable: IEnumerable[ListItemStructure],value: ListItemStructure) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class NamedElement(BlockElement):
 """
 Identifies an element within the hierarchy of elements under a System.Windows.Documents.FixedPage.

 

 NamedElement()
 """
 NameReference=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the element in the System.Windows.Documents.FixedPage markup hierarchy that provides the content for the parent of the System.Windows.Documents.DocumentStructures.NamedElement.



Get: NameReference(self: NamedElement) -> str



Set: NameReference(self: NamedElement)=value

"""



class ParagraphStructure(SemanticBasicElement,IAddChild,IEnumerable[NamedElement],IEnumerable):
 """
 Represents a paragraph in a document.

 

 ParagraphStructure()
 """
 def Add(self,element):
  """
  Add(self: ParagraphStructure,element: NamedElement)

   Adds a named element to the paragraph.

  

   element: The element to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[NamedElement](enumerable: IEnumerable[NamedElement],value: NamedElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class SectionStructure(SemanticBasicElement,IAddChild,IEnumerable[BlockElement],IEnumerable):
 """
 Represents a section of content in a document.

 

 SectionStructure()
 """
 def Add(self,element):
  """
  Add(self: SectionStructure,element: BlockElement)

   Adds a block to the section.

  

   element: The block element to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[BlockElement](enumerable: IEnumerable[BlockElement],value: BlockElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class StoryBreak(BlockElement):
 """
 Identifies the start or end of story composed of one or more System.Windows.Documents.DocumentStructures.StoryFragment elements.

 

 StoryBreak()
 """

class StoryFragment(object,IAddChild,IEnumerable[BlockElement],IEnumerable):
 """
 Represents all or part of a story within an XPS document.

 

 StoryFragment()
 """
 def Add(self,element):
  """
  Add(self: StoryFragment,element: BlockElement)

   Add a block to the story fragment.

  

   element: The block to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[BlockElement](enumerable: IEnumerable[BlockElement],value: BlockElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 FragmentName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the story fragment.



Get: FragmentName(self: StoryFragment) -> str



Set: FragmentName(self: StoryFragment)=value

"""

 FragmentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of fragment.



Get: FragmentType(self: StoryFragment) -> str



Set: FragmentType(self: StoryFragment)=value

"""

 StoryName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the story.



Get: StoryName(self: StoryFragment) -> str



Set: StoryName(self: StoryFragment)=value

"""



class StoryFragments(object,IAddChild,IEnumerable[StoryFragment],IEnumerable):
 """
 Represents a set of one or more System.Windows.Documents.DocumentStructures.StoryFragment elements.

 

 StoryFragments()
 """
 def Add(self,storyFragment):
  """
  Add(self: StoryFragments,storyFragment: StoryFragment)

   Adds a System.Windows.Documents.DocumentStructures.StoryFragment to the 

    System.Windows.Documents.DocumentStructures.StoryFragments collection.

  

  

   storyFragment: The System.Windows.Documents.DocumentStructures.StoryFragment to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[StoryFragment](enumerable: IEnumerable[StoryFragment],value: StoryFragment) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

class TableCellStructure(SemanticBasicElement,IAddChild,IEnumerable[BlockElement],IEnumerable):
 """
 Represents a cell in a table.

 

 TableCellStructure()
 """
 def Add(self,element):
  """
  Add(self: TableCellStructure,element: BlockElement)

   Adds a block element to the table cell.

  

   element: The element to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[BlockElement](enumerable: IEnumerable[BlockElement],value: BlockElement) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 ColumnSpan=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of columns spanned by the cell.



Get: ColumnSpan(self: TableCellStructure) -> int



Set: ColumnSpan(self: TableCellStructure)=value

"""

 RowSpan=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of rows spanned by the cell.



Get: RowSpan(self: TableCellStructure) -> int



Set: RowSpan(self: TableCellStructure)=value

"""



class TableRowGroupStructure(SemanticBasicElement,IAddChild,IEnumerable[TableRowStructure],IEnumerable):
 """
 Represents a set of one or more rows in a table.

 

 TableRowGroupStructure()
 """
 def Add(self,tableRow):
  """
  Add(self: TableRowGroupStructure,tableRow: TableRowStructure)

   Adds a row to the table row group.

  

   tableRow: The row to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[TableRowStructure](enumerable: IEnumerable[TableRowStructure],value: TableRowStructure) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class TableRowStructure(SemanticBasicElement,IAddChild,IEnumerable[TableCellStructure],IEnumerable):
 """
 Represents a row of one or more cells in a table.

 

 TableRowStructure()
 """
 def Add(self,tableCell):
  """
  Add(self: TableRowStructure,tableCell: TableCellStructure)

   Adds a cell to a table row.

  

   tableCell: The cell to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[TableCellStructure](enumerable: IEnumerable[TableCellStructure],value: TableCellStructure) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class TableStructure(SemanticBasicElement,IAddChild,IEnumerable[TableRowGroupStructure],IEnumerable):
 """
 Represents a table in a document.

 

 TableStructure()
 """
 def Add(self,tableRowGroup):
  """
  Add(self: TableStructure,tableRowGroup: TableRowGroupStructure)

   Adds a group of rows to a table.

  

   tableRowGroup: The group of rows to add.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[TableRowGroupStructure](enumerable: IEnumerable[TableRowGroupStructure],value: TableRowGroupStructure) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass




class COMException(ExternalException,ISerializable,_Exception):
 """
 The exception that is thrown when an unrecognized HRESULT is returned from a COM method call.

 

 COMException()

 COMException(message: str)

 COMException(message: str,inner: Exception)

 COMException(message: str,errorCode: int)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def ToString(self):
  """
  ToString(self: COMException) -> str

  

   Converts the contents of the exception to a string.

   Returns: A string containing the System.Exception.HResult,System.Exception.Message,

    System.Exception.InnerException,and System.Exception.StackTrace properties of the exception.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,inner: Exception)

  __new__(cls: type,message: str,errorCode: int)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass



class AutoCompleteStringCollection(object,IList,ICollection,IEnumerable):
 """
 Contains a collection of strings to use for the auto-complete feature on certain Windows Forms controls.

 

 AutoCompleteStringCollection()
 """
 def Add(self,value):
  """
  Add(self: AutoCompleteStringCollection,value: str) -> int

  

   Inserts a new System.String into the collection.

  

   value: The System.String to add to the collection.

   Returns: The position in the collection where the System.String was added.
  """
  pass
 def AddRange(self,value):
  """
  AddRange(self: AutoCompleteStringCollection,value: Array[str])

   Adds the elements of a System.String collection to the end.

  

   value: The strings to add to the collection.
  """
  pass
 def Clear(self):
  """
  Clear(self: AutoCompleteStringCollection)

   Removes all strings from the collection.
  """
  pass
 def Contains(self,value):
  """
  Contains(self: AutoCompleteStringCollection,value: str) -> bool

  

   Indicates whether the System.String exists within the collection.

  

   value: The System.String for which to search.

   Returns: true if the System.String exists within the collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: AutoCompleteStringCollection,array: Array[str],index: int)

   Copies an array of System.String objects into the collection,starting at the specified position.

  

   array: The System.String objects to add to the collection.

   index: The position within the collection at which to start the insertion.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: AutoCompleteStringCollection) -> IEnumerator

  

   Returns an enumerator that iterates through the 

    System.Windows.Forms.AutoCompleteStringCollection.

  

   Returns: An enumerator that iterates through the collection.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: AutoCompleteStringCollection,value: str) -> int

  

   Obtains the position of the specified string within the collection.

  

   value: The System.String for which to search.

   Returns: The index for the specified item.
  """
  pass
 def Insert(self,index,value):
  """
  Insert(self: AutoCompleteStringCollection,index: int,value: str)

   Inserts the string into a specific index in the collection.

  

   index: The position at which to insert the string.

   value: The string to insert.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: AutoCompleteStringCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.AutoCompleteStringCollection.CollectionChanged event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def Remove(self,value):
  """
  Remove(self: AutoCompleteStringCollection,value: str)

   Removes a string from the collection.

  

   value: The System.String to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: AutoCompleteStringCollection,index: int)

   Removes the string at the specified index.

  

   index: The zero-based index of the string to remove.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of items in the System.Windows.Forms.AutoCompleteStringCollection .



Get: Count(self: AutoCompleteStringCollection) -> int



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the contents of the collection are read-only.



Get: IsReadOnly(self: AutoCompleteStringCollection) -> bool



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether access to the System.Windows.Forms.AutoCompleteStringCollection is synchronized (thread safe).



Get: IsSynchronized(self: AutoCompleteStringCollection) -> bool



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that can be used to synchronize access to the System.Windows.Forms.AutoCompleteStringCollection.



Get: SyncRoot(self: AutoCompleteStringCollection) -> object



"""


 CollectionChanged=None




"""
Rpw Logger

Usage:

    >>> from rpw.utils.logger import logger
    >>> logger.info('My logger message')
    >>> logger.error('My error message')

"""

import sys


class mockLoggerWrapper():
    def __init__(*args, **kwargs):
        pass

    def __getattr__(self, *args, **kwargs):
        return mockLoggerWrapper(*args, **kwargs)

    def __call__(self, *args, **kwargs):
        pass


class LoggerWrapper():
    """
    Logger Wrapper to extend loggers functionality.
    The logger is called in the same as the regular python logger,
    but also as a few extra features.

    >>> logger.info('Message')
    [INFO]  Message

    Log Title

    >>> logger.title('Message')
    =========
    Message
    =========

    Disable logger

    >>> logger.disable()

    Log Errors: This method appends errmsg to self.errors.
    This allows you to check  if an error occured, and if it did not,
    close console window.

    >>> logger.error('Message')
    [ERROR]  Message
    >>> print(logger.errors)
    ['Message']

    """

    def __init__(self):

        handler = logging.StreamHandler(sys.stdout)
        formatter = logging.Formatter("[%(levelname)s] %(message)s")
        # TODO: Show Module
        # formatter = logging.Formatter("[%(levelname)s] %(message)s [%(module)s:%(lineno)s]")
        handler.setFormatter(formatter)

        logger = logging.getLogger('rpw_logger')
        logger.addHandler(handler)
        logger.setLevel(logging.INFO)

        handler_title = logging.StreamHandler(sys.stdout)
        formatter_title = logging.Formatter("%(message)s")
        handler_title.setFormatter(formatter_title)

        logger_title = logging.getLogger('rpw_logger_title')
        logger_title.addHandler(handler_title)
        logger_title.setLevel(logging.INFO)

        self._logger = logger
        self._logger_title = logger_title
        self.errors = []

    def disable(self):
        """ Sets logger level to logging.CRICITAL """
        self._logger.setLevel(logging.CRITICAL)

    def verbose(self, verbose):
        """
        Sets logger to Verbose.

        Args:
            (bool): True to set `logger.DEBUG`, False to set to `logging.INFO`.

        Usage:
            >>> logger.verbose(True)

        """
        if verbose:
            self._logger.setLevel(logging.DEBUG)
        else:
            self._logger.setLevel(logging.INFO)

    def title(self, msg):
        """ Log Message on logging.INFO level with lines above and below """
        print('=' * 100)
        self._logger_title.info(msg)
        print('=' * 100)

    def info(self, msg):
        """ Log Message on logging.INFO level """
        self._logger.info(msg)

    def debug(self, msg):
        """ Log Message on logging.DEBUG level """
        self._logger.debug(msg)

    def warning(self, msg):
        """ Log Message on logging.WARNING level """
        self._logger.warning(msg)

    def error(self, msg):
        """ Log Message on logging.ERROR level """
        self._logger.error(msg)
        self.errors.append(msg)

    def critical(self, msg):
        """ Log Message on logging.CRITICAL level """
        self._logger.critical(msg)

    def setLevel(self, level):
        self._logger.setLevel(level)

def deprecate_warning(depracated, replaced_by=None):
    msg = '{} has been deprecated and will be removed soon.'.format(depracated)
    if replaced_by:
        msg += ' Use {} instead'.format(replaced_by)
    logger.warning(msg)

try:
    import logging
except ImportError:
    # In Dynamo, Use Mock Logger
    logger = mockLoggerWrapper()
else:
    # In PyRevit, Use Logger
    logger = LoggerWrapper()



class MaskInputRejectedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.MaskedTextBox.MaskInputRejected event.

 

 MaskInputRejectedEventArgs(position: int,rejectionHint: MaskedTextResultHint)
 """
 @staticmethod
 def __new__(self,position,rejectionHint):
  """ __new__(cls: type,position: int,rejectionHint: MaskedTextResultHint) """
  pass
 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the position in the mask corresponding to the invalid input character.



Get: Position(self: MaskInputRejectedEventArgs) -> int



"""

 RejectionHint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an enumerated value that describes why the input character was rejected.



Get: RejectionHint(self: MaskInputRejectedEventArgs) -> MaskedTextResultHint



"""





class StackTrace(object):
 """
 Represents a stack trace,which is an ordered collection of one or more stack frames.

 

 StackTrace()

 StackTrace(fNeedFileInfo: bool)

 StackTrace(skipFrames: int)

 StackTrace(skipFrames: int,fNeedFileInfo: bool)

 StackTrace(e: Exception)

 StackTrace(e: Exception,fNeedFileInfo: bool)

 StackTrace(e: Exception,skipFrames: int)

 StackTrace(e: Exception,skipFrames: int,fNeedFileInfo: bool)

 StackTrace(frame: StackFrame)

 StackTrace(targetThread: Thread,needFileInfo: bool)
 """
 def GetFrame(self,index):
  """
  GetFrame(self: StackTrace,index: int) -> StackFrame

  

   Gets the specified stack frame.

  

   index: The index of the stack frame requested.

   Returns: The specified stack frame.
  """
  pass
 def GetFrames(self):
  """
  GetFrames(self: StackTrace) -> Array[StackFrame]

  

   Returns a copy of all stack frames in the current stack trace.

   Returns: An array of type System.Diagnostics.StackFrame representing the function calls in the stack 

    trace.
  """
  pass
 def ToString(self):
  """
  ToString(self: StackTrace) -> str

  

   Builds a readable representation of the stack trace.

   Returns: A readable representation of the stack trace.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,fNeedFileInfo: bool)

  __new__(cls: type,skipFrames: int)

  __new__(cls: type,skipFrames: int,fNeedFileInfo: bool)

  __new__(cls: type,e: Exception)

  __new__(cls: type,e: Exception,fNeedFileInfo: bool)

  __new__(cls: type,e: Exception,skipFrames: int)

  __new__(cls: type,e: Exception,skipFrames: int,fNeedFileInfo: bool)

  __new__(cls: type,frame: StackFrame)

  __new__(cls: type,targetThread: Thread,needFileInfo: bool)
  """
  pass
 FrameCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of frames in the stack trace.



Get: FrameCount(self: StackTrace) -> int



"""


 METHODS_TO_SKIP=0




class DataObjectAttribute(Attribute,_Attribute):
 """
 Identifies a type as an object suitable for binding to an System.Web.UI.WebControls.ObjectDataSource object. This class cannot be inherited.

 

 DataObjectAttribute()

 DataObjectAttribute(isDataObject: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: DataObjectAttribute,obj: object) -> bool

  

   Determines whether this instance of System.ComponentModel.DataObjectAttribute fits the pattern 

    of another object.

  

  

   obj: An object to compare with this instance of System.ComponentModel.DataObjectAttribute.

   Returns: true if this instance is the same as the instance specified by the obj parameter; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataObjectAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: DataObjectAttribute) -> bool

  

   Gets a value indicating whether the current value of the attribute is the default value for the 

    attribute.

  

   Returns: true if the current value of the attribute is the default; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,isDataObject=None):
  """
  __new__(cls: type)

  __new__(cls: type,isDataObject: bool)
  """
  pass
 def __ne__(self,*args):
  pass
 IsDataObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an object should be considered suitable for binding to an System.Web.UI.WebControls.ObjectDataSource object at design time.



Get: IsDataObject(self: DataObjectAttribute) -> bool



"""


 DataObject=None
 Default=None
 NonDataObject=None




class DataGridViewRowEventArgs(EventArgs):
 """
 Provides data for row-related System.Windows.Forms.DataGridView events.

 

 DataGridViewRowEventArgs(dataGridViewRow: DataGridViewRow)
 """
 @staticmethod
 def __new__(self,dataGridViewRow):
  """ __new__(cls: type,dataGridViewRow: DataGridViewRow) """
  pass
 Row=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.DataGridViewRow associated with the event.



Get: Row(self: DataGridViewRowEventArgs) -> DataGridViewRow



"""





class MouseEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Control.MouseUp,System.Windows.Forms.Control.MouseDown,and System.Windows.Forms.Control.MouseMove events.

 

 MouseEventArgs(button: MouseButtons,clicks: int,x: int,y: int,delta: int)
 """
 @staticmethod
 def __new__(self,button,clicks,x,y,delta):
  """ __new__(cls: type,button: MouseButtons,clicks: int,x: int,y: int,delta: int) """
  pass
 Button=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets which mouse button was pressed.



Get: Button(self: MouseEventArgs) -> MouseButtons



"""

 Clicks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of times the mouse button was pressed and released.



Get: Clicks(self: MouseEventArgs) -> int



"""

 Delta=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a signed count of the number of detents the mouse wheel has rotated,multiplied by the WHEEL_DELTA constant. A detent is one notch of the mouse wheel.



Get: Delta(self: MouseEventArgs) -> int



"""

 Location=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the location of the mouse during the generating mouse event.



Get: Location(self: MouseEventArgs) -> Point



"""

 X=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the x-coordinate of the mouse during the generating mouse event.



Get: X(self: MouseEventArgs) -> int



"""

 Y=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the y-coordinate of the mouse during the generating mouse event.



Get: Y(self: MouseEventArgs) -> int



"""


